Lua_WildSecretRankWindow = class("Lua_WildSecretRankWindow", Lua_Window)
function Lua_WildSecretRankWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.MAIN_MENU_LAYER;
	self.windowName = "Lua_WildSecretRankWindow";
	self.skinName = "WildSecretRankWindow_skin";
	self.isFullSizeWin = true;
	self.showBlackMask = true;
end

function Lua_WildSecretRankWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("WILD_SECRET_RANK", self, self.updateRankInfo);
	self:addLuaEvent("WILD_SECRET_LIKE", self, self.updateRankLike);
	self:addLuaEvent("WILD_SECRET_LIKE_CLICK", self, self.onLike);
	self:addLuaEvent("WILD_SECRET_CHECK_CLICK", self, self.onCheck);

	self.rankArr = Array();
	self.topPos = {{2, -230}, {-235, -290}, {236, -290}};
	self.topArr = Array();
	local item
	for i = 1, 3 do
		item = Lua_WildSecretRankTopItem.new(self.content);
		item.contentName = "topRank_"..i;
		item:setRectAnchor(1);
		item:setLocation(self.topPos[i][1], self.topPos[i][2], 0);
		item:setRank(i);
		self.topArr:add(item);
	end

	self.itemList = Lua_DragList.new(self.content, 688, 540 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -175, 0);
	self.itemList.tweenId = 2008;
	self.itemList.delayTween = true;
	self.itemList.callBackOwner = self;
	self.itemList.turnPageCallBack = self.turePage;
	self.itemList:setListCell(Lua_WildSecretRankItem, 688, 125, 1);
	self.itemList:setCellSpacing(0, 5);

	self.myAvatarItem = Lua_AvatarItem.new(self.content);
	self.myAvatarItem:setRectAnchor(7);
	self.myAvatarItem:setScale(0.7, 0.7, 1);
	self.myAvatarItem:setLocation(-147, 186, 0);

	self.myRankNum = Lua_NumberImage.new(self.content);
	self.myRankNum:setRectAnchor(7);
	self.myRankNum:setLocation(-270.5, 186, 0);
	self.myRankNum.numOffsetX = -4;
	self.myRankNum.numAtlas = "number";
	self.myRankNum.preStr = "xui_phb_number_";

	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.buttonList:setRectAnchor(7);
	self.buttonList:setRectPivot(5);
	self.buttonList.pivot = -1;
	self.buttonList:setLocation(360, 53.5, 0);
	self.buttonList:setButtonStyle("common_altas_1", "ui_common_button_001_b", "ui_common_button_001_b", 118, 108, 0.01, 1);
	self.buttonList:setButtonLine("common_altas_1", "ui_common_line_011", 2, 108, 0, 0, 1);
	self.buttonList:setButtonItem(120, 108);
	self.buttonList:setRedPoint(40, 40);
	self.buttonList:setClickCallBack(self, self.onButtonClick);
	self.buttonList:setData(DataCenter.wildSecretUtil.rankList);

	self.listBg:SetDimensions(720, 563 + self.adaptHeight);
	self.checkReward:addClickFuntion(self, self.onCheckReward);
	self.myBtnLike:addClickFuntion(self, self.onLikeClick);
	self.myBtnCheck:addClickFuntion(self, self.onCheckClick);
end

function Lua_WildSecretRankWindow:dispose()
	self:stopTimer();
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.myAvatarItem then
		self.myAvatarItem:dispose();
		self.myAvatarItem = nil;
	end
	if self.myRankNum then
		self.myRankNum:dispose();
		self.myRankNum = nil;
	end
	if self.topArr then
		self.topArr:dispose();
		self.topArr:clear();
		self.topArr = nil;
	end
	if self.buttonList then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildSecretRankWindow:onScreenResize()
	self:superCall("onScreenResize")
	self.listBg:SetDimensions(720, 563 + self.adaptHeight);
	self.itemList:setContentRect(708, 540 + self.adaptHeight);
end

function Lua_WildSecretRankWindow:showWin(param)
	self:superCall("showWin", param);
	self.buttonList:setSelected(param);
end

function Lua_WildSecretRankWindow:onButtonClick(index, data)
	self.index = index;
	self.bRefresh = true;
	self.checkReward:setEnable(index == 2);
	if index == 1 then
		self.nameText:setLangValue(701065);
		self.valueLabel:setLangValue(701067);
	else
		self.nameText:setLangValue(701066);
		self.valueLabel:setLangValue(701068);
	end
	self.itemList.showTween = true;
	self:startTimer();
	self:onTimer();
	self:turePage(0);
end

function Lua_WildSecretRankWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_WildSecretRankWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_WildSecretRankWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_WildSecretRankWindow:onTimer()
	local second = DataCenter.wildSecretData.stageSettleTick - DataCenter.roleData.serverTime;
	if self.index == 2 then
		second = DataCenter.wildSecretData.mineSettleTick - DataCenter.roleData.serverTime;
	end
	if second > 0 then
		self.timeText.text = LanUtil.formateStr(202543, Lua_TimeTransform.transSeconds18(second));
	else
		self:stopTimer();
		self.timeText.text = nil;
	end
end

function Lua_WildSecretRankWindow:turePage(page)
	page = page or 1
	if self.index == 1 then
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sStageRank(page);
	else
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeRank(page);
	end
end

function Lua_WildSecretRankWindow:updateRankInfo(msg)
	self:updateLikeTimes(msg.left_praise_times);

	if self.bRefresh then
		local len = self.rankArr:getSize();
		local num = len - #msg.role_list;
		while (num > 0) do
			self.rankArr:remove();
			num = num - 1;
		end
		for i = 1, #msg.role_list do
			if i > len then
				self.rankArr:add(msg.role_list[i]);
			else
				self.rankArr[i] = msg.role_list[i];
			end
		end
	else
		for i = 1, #msg.role_list do
			self.rankArr:add(msg.role_list[i]);
		end
	end
	self.itemList.isPageEnd = (msg.is_end == 1);
	self:updateRankList();
	self:updateTopRank();
	self.bRefresh = false;
	
	self.data = msg.self_rank;
	if self.data.rank < 1 then
		self.myNoneRankSp:setEnable(true);
		self.myRankNum:setEnable(false);
	else
		self.myNoneRankSp:setEnable(false);
		self.myRankNum:setEnable(true);
		self.myRankNum.num = self.data.rank;
	end

	self.myNameTxt.text = self.data.show_role.name;
	
	self.myAvatarItem:setRoleId(self.data.id);
	self.myAvatarItem:setRoleDressUp(self.data.show_role.dress_info, true);
	self.myAvatarItem:setRoleLevel2(self.data.show_role.level);

	if strIsNullOrEmpty(self.data.show_role.league_name) then
		self.myLeagueTxt:setLangValue(202503);
	else
		self.myLeagueTxt.text = self.data.show_role.league_name;
	end

	local width;
	if self.index == 1 then
		self.myIcon:setEnable(false);
		self.myBtnCheck:setEnable(false);
		if self.data.stage_id == 0 then
			self.myValueTxt:setLangValue(701072);
		else
			local config = DataCenter.wildSecretUtil:getStageConfig(self.data.stage_id);
			self.myValueTxt.text = LanUtil.formateStr(701069, tostring(config.floor), tostring(config.stage));
		end
		self.myValueTxt:setLocation(0, 0, 0);
		self.myValueTxt:resetSize();
		width = self.myValueTxt.width;
	else
		self.myIcon:setEnable(true);
		width = Mathf.Floor(self.myIcon.width * 0.3);
			
		self.myValueTxt:setLocation(width, 0, 0);
		self.myValueTxt.text = self.data.score;
		self.myValueTxt:resetSize();
		width = width + self.myValueTxt.width;

		self.myBtnCheck:setEnable(true);
		self.myBtnCheck:setLocation(width + 5, 0, 0);
		width = width + self.myBtnCheck.width + 5;
	end
	LuaUtil.setObjPos(self.myValueObject, 160 - width / 2, 185, 0);
	self.myLikeTxt.text = self.data.praise_num;
end

function Lua_WildSecretRankWindow:updateRankLike(msg)
	self:updateLikeTimes(msg.left_praise_times);
	for i = 1, self.rankArr:getSize() do
		if self.rankArr[i].id == msg.role_info.id then
			self.rankArr[i] = msg.role_info;
			break;
		end
	end
	self:updateRankList();
	self:updateTopRank();
end

function Lua_WildSecretRankWindow:updateLikeTimes(times)
	self.left_praise_times = times;
	local limitTimes = DataCenter.wildSecretUtil.limitLikeTimes;
	self.leftLikeText.text = LanUtil.formateStr(202539, tostring(times), tostring(limitTimes))
end

function Lua_WildSecretRankWindow:updateRankList()
	local len = self.rankArr:getSize() - 3;
	if len > 0 then
		self.itemList:setEnable(true);
		self.itemList.customParam = self.index;
		self.itemList:setArrayData(self.rankArr, 4);
		if self.bRefresh then
			self.itemList:moveToIndex(1, true);
		end
		self:showNone(false);
	else
		self.itemList:setEnable(false);
		self:showNone(true);
	end
end

function Lua_WildSecretRankWindow:showNone(value)
	if value then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createImage(self.content, "/images/championship/xui_jys_widget_18.png", 0, -170, 0, 0);

			self.noneText = UICreate.createLabel(self.content, nil, 1.5, -220, 100, 40, 36);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("7A6C74");
			self.noneText:setLangValue(202502);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end

function Lua_WildSecretRankWindow:updateTopRank()
	for i = 1, 3 do
		self.topArr[i]:setData(self.index, self.rankArr[i]);
	end
	self:updateTween();
end

function Lua_WildSecretRankWindow:updateTween()
	if not self.bRefresh then
		return
	end
	
	if self.tweenName then
		DataCenter.winTweenManager:removeWinTween(self.tweenName)
	end
	self.tweenName = DataCenter.winTweenManager:createWinTween(self.windowName, self.windowObj.transform);
end

function Lua_WildSecretRankWindow:onLike(data)
	if DataCenter.roleData:isMyself(data.id) then
		OperateAlert.showLangValue(202540);
		return;
	end
	if self.left_praise_times and self.left_praise_times <= 0 then
		OperateAlert.showLangValue(202541);
		return;
	end
	if data.is_praised == 1 then
		OperateAlert.showLangValue(202542);
		return;
	end
	if self.index == 1 then
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sStageRankLike(data.id);
	else
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeRankLike(data.id);
	end
end

function Lua_WildSecretRankWindow:onCheck(data)
	Lua_WindowUtil.openWin("Lua_WildSecretRankTipsWindow", Lua_WinParam.ACTION_OPEN, { data = data.data, posX = 160, posY = data.posY + self.itemList.curSubPos - 275});
end

function Lua_WildSecretRankWindow:onCheckReward(go)
	Lua_WindowUtil.openWin("Lua_WildSecretRankRewardWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_WildSecretRankWindow:onLikeClick(go)
	OperateAlert.showLangValue(202540);
end

function Lua_WildSecretRankWindow:onCheckClick(go)
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_WildSecretRankTipsWindow", Lua_WinParam.ACTION_OPEN, { data = self.data, anchorValue = 7, posX = 160, posY = 100 });
end










Lua_WildSecretRankTopItem = class("Lua_WildSecretRankTopItem", Lua_DisplayObject)
function Lua_WildSecretRankTopItem:ctor(p)
	self:superCall("ctor", p, "WildSecretRankTopItem_skin");
end

function Lua_WildSecretRankTopItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setCanClick(true);

	self.btnLike:addClickFuntion(self, self.onLikeClick);
	self.btnCheck:addClickFuntion(self, self.onCheckClick);
end

function Lua_WildSecretRankTopItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildSecretRankTopItem:setRank(value)
	self.bg:setAltas("rank_altas", "xui_phb_bg_"..(value + 1));
	self.rankText.text = LanUtil.formateStr(202538, convert_arab_to_chinese(value));
	if value == 1 then
		self.rankText:setLocation(0, 26, 0);
		self.rankText.fontSize = 30;
		self.rankText.colorStr = Lua_ColorDefine.transColorStr("FCF6AF");

		self.nameText:setLocation(0, -18, 0);
		self.nameText:SetDimensions(182, 31);
		self.nameText.fontSize = 26;

		-- self.valueTxt:setLocation(0, -62, 0);
		self.valueTxt.colorStr = Lua_ColorDefine.transColor("FFFFFF");
		-- self.valueTxt.effectColorStr = Lua_ColorDefine.transColorStr("876A2A");

		self.btnLike:setLocation(0, -110, 0);
		self.likeNumTxt:setLocation(-20, -106, 0);

		self.avatarItem:setScale(0.9, 0.9, 1);
		self.avatarItem:setLocation(0, 108, 0);
	else
		self.rankText:setLocation(0, 28, 0);
		self.rankText.fontSize = 26;
		self.rankText.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");

		self.nameText:setLocation(0, -7, 0);
		self.nameText:SetDimensions(155, 31);
		self.nameText.fontSize = 26;
		
		-- self.valueTxt:setLocation(0, -48, 0);
		self.valueTxt.colorStr = Lua_ColorDefine.transColor("FFFFFF");
		if value == 2 then
			self.nameText.effectColorStr = Lua_ColorDefine.transColorStr("606A93");
			-- self.valueTxt.effectColorStr = Lua_ColorDefine.transColorStr("606A93");
		else
			self.nameText.effectColorStr = Lua_ColorDefine.transColorStr("876A2A");
			-- self.valueTxt.effectColorStr = Lua_ColorDefine.transColorStr("876A2A");
		end

		self.btnLike:setLocation(0, -85, 0);
		self.likeNumTxt:setLocation(-20, -81, 0);

		self.avatarItem:setScale(0.8, 0.8, 1);
		self.avatarItem:setLocation(0, 96, 0);
	end
end

function Lua_WildSecretRankTopItem:setData(index, data)
	self.data = data;
	if data == nil then
		self.nameText:setLangValue(202500);
		self.valueObject:SetActive(false);
		self.btnLike:setEnable(false);
		self.likeNumTxt:setEnable(false);
		self.avatarItem:init();
	else
		self.nameText.text = data.show_role.name;
		self.valueObject:SetActive(true);

		local width;
		if index == 1 then
			self.icon:setEnable(false);
			self.btnCheck:setEnable(false);
			local config = DataCenter.wildSecretUtil:getStageConfig(data.stage_id);
			self.valueTxt.text = LanUtil.formateStr(701069, tostring(config.floor), tostring(config.stage));
			self.valueTxt:setLocation(0, 0, 0);
			self.valueTxt:resetSize();
			width = self.valueTxt.width;
		else
			self.icon:setEnable(true);
			width = Mathf.Floor(self.icon.width * 0.3);
			
			self.valueTxt:setLocation(width, 0, 0);
			self.valueTxt.text = data.score;
			self.valueTxt:resetSize();
			width = width + self.valueTxt.width;

			self.btnCheck:setEnable(true);
			self.btnCheck:setLocation(width + 5, 0, 0);
			width = width + self.btnCheck.width + 5;
		end
		if data.rank == 1 then
			LuaUtil.setObjPos(self.valueObject, -width / 2, -62, 0);
		else
			LuaUtil.setObjPos(self.valueObject, -width / 2, -48, 0);
		end

		self.btnLike:setEnable(true);
		self.likeNumTxt:setEnable(true);
		self.likeNumTxt.text = data.praise_num;

		self.avatarItem:setRoleId(data.id, data.show_role.server_flag);
		self.avatarItem:setRoleDressUp(data.show_role.dress_info, true);
		self.avatarItem:setRoleLevel2(data.show_role.level);
	end
end

function Lua_WildSecretRankTopItem:onLikeClick(go)
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("WILD_SECRET_LIKE_CLICK", self.data);
end

function Lua_WildSecretRankTopItem:onCheckClick(go)
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_WildSecretRankTipsWindow", Lua_WinParam.ACTION_OPEN, { data = self.data, anchorValue = 1, posX = self.x, posY = -505 });
end










Lua_WildSecretRankItem = class("Lua_WildSecretRankItem", Lua_ListCell)
function Lua_WildSecretRankItem:ctor(p)
	self:superCall("ctor", p, "WildSecretRankItem_skin");
end

function Lua_WildSecretRankItem:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.7, 0.7, 1);
	self.avatarItem:setLocation(-147, 0, 0);

	self.btnLike:addClickFuntion(self, self.onLikeClick);
	self.btnCheck:addClickFuntion(self, self.onCheckClick);
end

function Lua_WildSecretRankItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildSecretRankItem:setCustomParam(customParam)
	self.index = customParam;
end

function Lua_WildSecretRankItem:setData(data)
	self.data = data;
	self.numTxt.text = data.rank;
	self.nameTxt.text = data.show_role.name;
	if strIsNullOrEmpty(data.show_role.league_name) then
		self.leagueTxt:setLangValue(202503);
	else
		self.leagueTxt.text = data.show_role.league_name;
	end

	local width;
	if self.index == 1 then -- 积分排行
		self.icon:setEnable(false);
		self.btnCheck:setEnable(false);
		local config = DataCenter.wildSecretUtil:getStageConfig(data.stage_id);
		self.valueTxt.text = LanUtil.formateStr(701069, tostring(config.floor), tostring(config.stage));
		self.valueTxt:setLocation(0, 0, 0);
		self.valueTxt:resetSize();
		width = self.valueTxt.width;
	else
		self.icon:setEnable(true);
		width = Mathf.Floor(self.icon.width * 0.3);
		
		self.valueTxt:setLocation(width, 0, 0);
		self.valueTxt.text = data.score;
		self.valueTxt:resetSize();
		width = width + self.valueTxt.width;

		self.btnCheck:setEnable(true);
		self.btnCheck:setLocation(width + 5, 0, 0);
		width = width + self.btnCheck.width + 5;
	end
	LuaUtil.setObjPos(self.valueObject, 160 - width / 2, 0, 0);

	self.likeNumTxt.text = data.praise_num;

	self.avatarItem:setRoleId(data.id, data.show_role.server_flag);
	self.avatarItem:setRoleDressUp(data.show_role.dress_info, true);
	self.avatarItem:setRoleLevel2(data.show_role.level);

	if data.is_praised == 1 then
		self.btnLike:setAltas("rank_altas", "xui_phb_btn_3_p");
	else
		self.btnLike:setAltas("rank_altas", "xui_phb_btn_3_n");
	end
end

function Lua_WildSecretRankItem:onLikeClick(go)
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("WILD_SECRET_LIKE_CLICK", self.data);
end

function Lua_WildSecretRankItem:onCheckClick(go)
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("WILD_SECRET_CHECK_CLICK", { data = self.data, posY = self.y });
end