Lua_WildLodeInfoWindow = class("Lua_WildLodeInfoWindow", Lua_Window)
function Lua_WildLodeInfoWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_WildLodeInfoWindow";
	self.skinName = "WildLodeInfoWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_WildLodeInfoWindow:buildShowItem()
	self:superCall("buildShowItem");
	LuaUtil.setRectSize(self.showObject, 720, 960);
	self.lineupArr = Array();

	self:addLuaEvent("UPDATE_HERO_LINEUP_INFO", self, self.onRequestInfo);
	self:addLuaEvent("WILD_SECRET_LODE_POINT_LINEUP", self, self.updateServerInfo);
	self:addLuaEvent("WILD_SECRET_LODE_REPLACE_CLICK", self, self.onReplaceClick);
	self:addLuaEvent("WILD_SECRET_LODE_FIGHT_CHECK", self, self.onAttackCheck);

	self.avatarItem = Lua_AvatarItem.new(self.showObject);
	self.avatarItem:setSiblingIndex(4);
	self.avatarItem:setRectAnchor(1);
	self.avatarItem:setScale(0.7, 0.7, 1);
	self.avatarItem:setLocation(-220, -200, 0);

	self.btnGiveUp:addClickFuntion(self, self.onGiveUpClick);
	self.btnLineup:addClickFuntion(self, self.onLineupClick);
end

function Lua_WildLodeInfoWindow:dispose()
	self:stopTimer();
	DataCenter.preLoadData:removeBySign("Lua_WildLodeAttackLineupWindow", self, self.onAttackSceneShow);
	DataCenter.preLoadData:removeBySign("Lua_WildLodeDefendLineupWindow", self, self.onDefendSceneShow);
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.lineupArr then
		self.lineupArr:dispose();
		self.lineupArr:clear();
		self.lineupArr = nil;
	end
	if self.rewardItem then
		self.rewardItem:dispose();
		self.rewardItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildLodeInfoWindow:showWin(param)
	self:superCall("showWin", param);
	self:onRequestInfo();
end

function Lua_WildLodeInfoWindow:onRequestInfo()
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodePointLineup(self.showData);
end

function Lua_WildLodeInfoWindow:updateServerInfo(msg)
	self.data = msg;
	local info = msg.mine_site_info;
	self.left_output_tick = info.left_output_tick;

	local config = DataCenter.wildSecretUtil:getLodePointConfig(info.mine_site_id);
	self.isSecure = DataCenter.wildSecretData:getMineRegionVo(config.region).isSecure;
	self.nameText.text = config.name;

	self.isRobot = tonumber(msg.show_role.id) == 0;
	if self.isRobot then
		self.avatarItem:setEnable(false);
		self.icon:setEnable(true);
		self.serverBg:setEnable(false);
		self.serverText:setEnable(false);
		self.roleNameText:setLangValue(701079);
		
		self.incomeLabel:setEnable(false);
		self.incomeIcon:setEnable(false);
		self.incomeCount:setEnable(false);
	else
		self.avatarItem:setEnable(true);
		-- self.avatarItem:setRoleId(msg.show_role.id, msg.show_role.server_flag);
		self.avatarItem:setRoleDressUp(msg.show_role.dress_info);
		self.avatarItem:setRoleLevel(msg.show_role.level);

		self.icon:setEnable(false);
		self.serverBg:setEnable(true);
		self.serverText:setEnable(true);
		self.serverText.text = LanUtil.formateStr(701049, msg.show_role.server_prev);
		self.roleNameText.text = msg.show_role.name;
		
		self.incomeLabel:setEnable(true);
		self.incomeIcon:setEnable(true);
		self.incomeCount:setEnable(true);
		self.incomeCount.text = info.total_profit;
	end
	-- if info.floor_per_hour_profit > 0 then
	-- 	self.incomeText.text = LanUtil.formateStr(701036, tostring(info.per_hour_profit), tostring(info.floor_per_hour_profit));
	-- else
	-- 	self.incomeText.text = LanUtil.formateStr(701073, tostring(info.per_hour_profit));
	-- end
	self.incomeText.text = LanUtil.formateStr(701073, tostring(info.per_hour_profit + info.floor_per_hour_profit));

	table.sort( msg.lineup, function(a, b) return a.index < b.index end )
	local len = #msg.lineup;
	local force = 0;
	local item;
	for i = 1, len do
		force = force + msg.lineup[i].force;
		item = self.lineupArr[i];
		if item == nil then
			item = Lua_WildLodeInfoItem.new(self.showObject);
			self.lineupArr:add(item);
		end
		item:setRectAnchor(1);
		item:setLocation(0, -421 + (i - 1) * -106, 0);
		item:setData(self.isRobot, msg.lineup[i]);
	end
	self.forceText.text = force;
	self.forceText:resetSize();
	self.forceIcon:setLocation(311 - self.forceText.width, -340, 0);
	self.winBg:SetDimensions(711, 760 + len * 100);
	LuaUtil.setRectSize(self.showObject, 720, 760 + len * 100);

	local second = tonumber(info.protect_end_tick) - DataCenter.roleData.serverTime;
	if second <= 0 then
		if msg.left_grab_times > 0 and not self.isRobot then
			self.tipsBg:setEnable(false);
			self.tipsText:setEnable(false);
			if self.rewardItem == nil then
				self.rewardItem = Lua_ItemIcon.new(self.showObject);
				self.rewardItem:setRectAnchor(7);
				self.rewardItem:setScale(0.8, 0.8, 1);
				self.rewardItem:setLocation(0, 235, 0);
				self.rewardItem:setCanClick(true);
			end
			local count = Mathf.Floor(info.total_profit * DataCenter.wildSecretUtil.grabRate + 0.5);
			local vo = Lua_ToolVo.createToolVo(201000047, count);
			self.rewardItem:setData(vo);
		else
			if self.rewardItem then
				self.rewardItem:setEnable(false);
			end
			self.tipsBg:setEnable(true);
			self.tipsText:setEnable(true);
			if self.isRobot then
				self.tipsText:setLangValue(701074);
			else
				self.tipsText:setLangValue(701050);
			end
		end
	else
		if self.rewardItem then
			self.rewardItem:setEnable(false);
		end
	end
	self.bRequestInfo = (second <= 0);

	if DataCenter.roleData:isMyself(msg.show_role.id) then
		self.btnGiveUp:setLangValue(701047);
		self.btnLineup:setLangValue(701048);
		self.desText:setLangValue(701054);
	else
		self.btnGiveUp:setLangValue(701045);
		self.btnLineup:setLangValue(701046);
		self.desText:setLangValue(701053);
	end

	self:startTimer();
	self:onTimer();
end

function Lua_WildLodeInfoWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_WildLodeInfoWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_WildLodeInfoWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_WildLodeInfoWindow:onTimer()
	if not self.isRobot then
		self.left_output_tick = self.left_output_tick - 1;
	end
	if self.left_output_tick > 0 then
		self.gatherTimeText.text = LanUtil.formateStr(701031, Lua_TimeTransform.transSeconds6(self.left_output_tick));
	else
		self.gatherTimeText.text = nil;
	end

	local second = tonumber(self.data.mine_site_info.protect_end_tick) - DataCenter.roleData.serverTime;
	if second > 0 then
		self.bProtect = true;
		self.tipsBg:setEnable(true);
		self.tipsText:setEnable(true);
		self.tipsText.text = LanUtil.formateStr(701052, Lua_TimeTransform.transSeconds6(second));
	else
		self.bProtect = false;
		if not self.bRequestInfo then
			self.bRequestInfo = true;
			self:onRequestInfo();
		end
		if self.data.left_grab_times > 0 and not self.isRobot then
			self.tipsBg:setEnable(false);
			self.tipsText:setEnable(false);
		else
			self.tipsBg:setEnable(true);
			self.tipsText:setEnable(true);
			if self.isRobot then
				self.tipsText:setLangValue(701074);
			else
				self.tipsText:setLangValue(701050);
			end
		end
	end
end

function Lua_WildLodeInfoWindow:onReplaceClick(num)
	self.replaceNum = num;
	self.templateId = Lua_FightDefine.TEMPLATE_ID_WILD_PVP_2;
	self:onAttackClick();
end

function Lua_WildLodeInfoWindow:onGiveUpClick(go)
	local restTick = DataCenter.wildSecretUtil.restTick;
	if restTick then
		local hour = tonumber(os.date("%H", DataCenter.roleData.serverTime));
		if hour >= restTick[1] and hour < restTick[2] then
			OperateAlert.showLangValue(701057);
			return;
		end
	end

	if self.isRobot then
		OperateAlert.showLangValue(701074);
		return;
	end

	if self.data == nil then
		return;
	end

	if DataCenter.roleData:isMyself(self.data.show_role.id) then
		if self.bProtect then
			OperateAlert.showLangValue(701080);
		else
			Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, { des = 701037, btnType = 1, owner = self, sureFun = self.onGiveUp });
		end
	else
		if DataCenter.wildSecretData.leftGrabTimes <= 0 then
			OperateAlert.showLangValue(701026);
			return;
		end
		
		if self.bProtect then
			OperateAlert.showLangValue(701082);
		else
			if self.data.left_grab_times > 0 then
				if self.isSecure then
					OperateAlert.showLangValue(701090);
					return;
				end

				self.templateId = Lua_FightDefine.TEMPLATE_ID_WILD_PVP_1;
				self:onAttackClick();
			else
				OperateAlert.showLangValue(701055);
			end
		end
	end
end

function Lua_WildLodeInfoWindow:onGiveUp()
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeGiveUp(self.data.mine_site_info.num);
	self:hide();
end

function Lua_WildLodeInfoWindow:onLineupClick(go)
	local restTick = DataCenter.wildSecretUtil.restTick;
	if restTick then
		local hour = tonumber(os.date("%H", DataCenter.roleData.serverTime));
		if hour >= restTick[1] and hour < restTick[2] then
			OperateAlert.showLangValue(701057);
			return;
		end
	end

	if self.data == nil then
		return;
	end

	if DataCenter.roleData:isMyself(self.data.show_role.id) then
		if self.bProtect then
			OperateAlert.showLangValue(701081);
		else
			self:onDefendClick();
		end
	else
		if self.bProtect then
			OperateAlert.showLangValue(701083);
		else
			if self.left_output_tick > 0 or self.isRobot then
				if not self.isRobot and self.isSecure then
					OperateAlert.showLangValue(701091);
					return;
				end

				if DataCenter.wildSecretData.isCanOccupy then
					self.templateId = Lua_FightDefine.TEMPLATE_ID_WILD_PVP_2;
					self:onAttackClick();
				else
					Lua_WindowUtil.openWin("Lua_WildLodeReplaceWindow", Lua_WinParam.ACTION_OPEN);
				end
			else
				OperateAlert.showLangValue(701056);
			end
		end
	end
end

function Lua_WildLodeInfoWindow:onDefendClick()
	local sceneId = DataCenter.wildSecretData:getLodeFightSceneId(self.data.mine_site_info.mine_site_id);
	DataCenter.preLoadData:preShowScene("Lua_WildLodeDefendLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onDefendSceneShow, nil, sceneId, 0);
end

function Lua_WildLodeInfoWindow:onDefendSceneShow(param, mp, success)
	if not success then return; end
	param = { lineup_type = 48 + self.data.mine_site_info.num, stage_id = self.data.mine_site_info.mine_site_id, team_num = #self.data.lineup };
	Lua_WindowUtil.openWin("Lua_WildLodeDefendLineupWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_WildLodeInfoWindow:onAttackClick()
	if self.templateId == Lua_FightDefine.TEMPLATE_ID_WILD_PVP_1 then
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeFightCheck(self.data.mine_site_info.mine_site_id, self.data.show_role.id, 1);
	else
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeFightCheck(self.data.mine_site_info.mine_site_id, self.data.show_role.id, 2);
	end
end

function Lua_WildLodeInfoWindow:onAttackCheck(msg)
	if msg.type == 0 then
		local sceneId = DataCenter.wildSecretData:getLodeFightSceneId(self.data.mine_site_info.mine_site_id);
		if sceneId == 0 then
			sceneId = DataCenter.heroLineupData:getFightLineupSceneId(self.templateId);
		end
		DataCenter.preLoadData:preShowScene("Lua_WildLodeAttackLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onAttackSceneShow, nil, sceneId, 0);
	else
		if msg.type == 1 then
			OperateAlert.showLangValue(701085);
		elseif msg.type == 2 then
			OperateAlert.showLangValue(701050);
		elseif msg.type == 3 then
			OperateAlert.showLangValue(701056);
		end
	end
end

function Lua_WildLodeInfoWindow:onAttackSceneShow(param, mp, success)
	if not success then return; end
	local lineupType;
	local len = #self.data.lineup;
	if self.templateId == Lua_FightDefine.TEMPLATE_ID_WILD_PVP_1 then -- 掠夺
		if len == 3 then
			lineupType = 52;
		else
			lineupType = 54 + len;
		end
	else
		if len == 3 then
			lineupType = 48;
		else
			lineupType = 52 + len;
		end
	end
	local data = Lua_LineupWinData.getData(self.templateId, nil, nil, nil, nil, lineupType, nil, self.data, self.replaceNum);
	Lua_WindowUtil.openWin("Lua_WildLodeAttackLineupWindow", Lua_WinParam.ACTION_OPEN, data);
	self.replaceNum = nil;
end










Lua_WildLodeInfoItem = class("Lua_WildLodeInfoItem", Lua_DisplayObject)
function Lua_WildLodeInfoItem:ctor(p)
	self:superCall("ctor", p, "WildLodeInfoItem_skin");
end

function Lua_WildLodeInfoItem:buildShowItem()
	self:superCall("buildShowItem");
	self.itemList = Array();
	local item;
	for i = 1, 6 do
		item = Lua_ItemIcon.new(self.content);
		item:setScale(0.7, 0.7, 1);
		item:setLocation(-210 + (i - 1) * 95, 0, 0);
		self.itemList:add(item);
	end
end

function Lua_WildLodeInfoItem:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList:clear();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_WildLodeInfoItem:setData(isRobot, data)
	self.teamText.text = LanUtil.formateStr(701051, convert_arab_to_chinese(data.index));
	local info;
	local vo;
	for i = 1, 6 do
		info = data.hero_list[i];
		if info and tonumber(info.hero_id) > 0 then
			vo = Lua_HeroVo.new(info.hero_id);
			vo:fromServer(info);
			vo.otherLineup = data.hero_list;
			self.itemList[i]:setCanClick(not isRobot);
			self.itemList[i]:setData(vo);
		else
			self.itemList[i]:setCanClick(false);
			self.itemList[i]:setData(nil);
		end
	end
end