Lua_WildLodePanel = class("Lua_WildLodePanel", Lua_DisplayObject)
function Lua_WildLodePanel:ctor(p)
	self:superCall("ctor", p, "WildLodePanel_skin");
end

function Lua_WildLodePanel:buildShowItem()
	self:superCall("buildShowItem");
	self.showHeight = 1274 + self.adaptHeight;
	self.subRectH = 0;
	self.subMinPos = 0;
	self.subMaxPox = 0;
	self.curPosY = 0;
	self.minY = -self.showHeight / 2;
	self.maxY = self.showHeight / 2;
	self.showList = Array();
	self.hideList = Array();

	self.showImg = UICreate.createImage(self.content, "/images/wild_secret/xui_mhyj_bg_12.png", 0, 0, 720, 1789);
	self.showImg.siblingIndex = 0;

	self.bgEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_mhmj_csm_03", "ui_mhmj_csm_03", 0, 0);
	self.bgEff.siblingIndex = 1;

	self.scrollContainer = UICreate.createScrollContainer(self.content, 0, 0, 720, self.showHeight);
	self.scrollContainer:setLocation(0, 28, 0);
	self.scrollContainer.bCreateContent = true;
	self.scrollContainer.horizontal = false;
	self.scrollContainer.vertical = true;
	self.scrollContainer.movementTypeValue = 2;
	self.scrollContainer.elasticity = 0.3;
	self.scrollContainer.inertia = true;
	self.scrollContainer:setScrollSize(0, self.subRectH);
	self.scrollContainer:setScrollPivot(4);
	self.scrollContainer:addValueChangedFun(self, self.onValueChanged);
	self.scrollContainer:addMousDownFuntion(self, self.onMouseDownFun);
	self.scrollContainer:addMouseUpFuntion(self, self.onMouseUpFun);
	self.scrollContainer.siblingIndex = 2;

	self.sub = self.scrollContainer.scrollContent;
	self.subRect = self.scrollContainer.scrollRect;

	self.recordRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.WildSecret_Lode_Record);
	self.recordRedPoint:setRectAnchor(1);
	self.recordRedPoint:setLocation(325, -300);

	self.occupyRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.WildSecret_Lode_Occupy);
	self.occupyRedPoint:setRectAnchor(7);
	self.occupyRedPoint:setLocation(315, 210);

	self.plunderRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.WildSecret_Lode_Plunder);
	self.plunderRedPoint:setRectAnchor(7);
	self.plunderRedPoint:setLocation(315, 328);

	self.btnHelp:addClickFuntion(self, self.onCheckHelp);
	self.btnRank:addClickFuntion(self, self.onCheckRank);
	self.btnRecord:addClickFuntion(self, self.onCheckRecord);
	self.btnReco:addClickFuntion(self, self.onCheckReco);
	self.btnLode:addClickFuntion(self, self.onCheckLode);

	self:addLuaEvent("FIGHTPLAY_COMPLETE", self, self.onFightPlayCompleted);
	self:addLuaEvent("WILD_SECRET_LODE_GIVEUP", self, self.onRequestInfo);
	self:addLuaEvent("WILD_SECRET_LODE_REGION", self, self.updateServerInfo);
	self:onRequestInfo();
	
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeTips(0);
	DataCenter.wildSecretData.reportList = nil;
	Lua_MsgUtil.callFunc("WILD_SECRET_LODE_REPORT");
end

function Lua_WildLodePanel:dispose()
	self:stopTimer();
	if self.showList then
		self.showList:dispose();
		self.showList:clear();
		self.showList = nil;
	end
	if self.hideList then
		self.hideList:dispose();
		self.hideList:clear();
		self.hideList = nil;
	end
	self.showImg = nil;
	self.sub = nil;
	self.subRect = nil;
	self.pressItem = nil;
	if self.recordRedPoint then
		self.recordRedPoint:dispose();
		self.recordRedPoint = nil;
	end
	if self.occupyRedPoint then
		self.occupyRedPoint:dispose();
		self.occupyRedPoint = nil;
	end
	if self.plunderRedPoint then
		self.plunderRedPoint:dispose();
		self.plunderRedPoint = nil;
	end
	self:superCall("dispose");
end

function Lua_WildLodePanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.showHeight = 1274 + adaptHeight;
	self.minY = -self.showHeight / 2;
	self.maxY = self.showHeight / 2;
	self.scrollContainer:SetDimensions(720, self.showHeight);
end

function Lua_WildLodePanel:onValueChanged()
	local posY = self.subRect.anchoredPosition.y;
	local value = posY - self.curPosY;
	self.curPosY = posY;

	local y = self.showImg.posY + (value * -0.015);
	self.showImg:setLocation(0, y, 0);

	self:updateDragItem();
end

function Lua_WildLodePanel:onMouseDownFun()
	self.startMouseX = CommonUtil.mousePositionX;
	self.startMouseY = CommonUtil.mousePositionY;
	self.startClickTime = getTime();
	self.pressItem = self:checkClick();
end

function Lua_WildLodePanel:onMouseUpFun()
	if self.pressItem then
		local dx = CommonUtil.mousePositionX - self.startMouseX;
		local dy = CommonUtil.mousePositionY - self.startMouseY;
		if getTime() - self.startClickTime <= 0.3 and Mathf.Abs(dx) + Mathf.Abs(dy) < 4 then
			self.pressItem:onPressClick()
		end
	end
	self.pressItem = nil;
end

function Lua_WildLodePanel:checkClick()
	if self.showList then
		local winPos = LuaUtil.getTouchPosInverseObj(self.sub);
		local len = self.showList:getSize();
		for i = 1, len do
			if self.showList[i].isActive and self.showList[i]:checkInBound(winPos.x, winPos.y) then
				return self.showList[i];
			end
		end
	end
    return nil;
end

function Lua_WildLodePanel:onRequestInfo()
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeRegionInfo();
end

function Lua_WildLodePanel:onFightPlayCompleted(templateId)
	if templateId == 1045 or templateId == 1046 then
		self:onRequestInfo();
	end
end

function Lua_WildLodePanel:updateServerInfo()
	self.plunderText.text = LanUtil.formateStr(701016, tostring(DataCenter.wildSecretData.leftGrabTimes));
	self:startTimer();
	self:onTimer();

	local arr = DataCenter.wildSecretData.mineRegionArr;
	local len = arr:getSize();
	local spaceVal = 520;
	local count = Mathf.Floor(len / 3);
	if len % 3 == 0 then
		self.subRectH = count * spaceVal - self.showHeight + spaceVal / 2;
	else
		self.subRectH = (count + 1) * spaceVal - self.showHeight;
	end
	self.subRectH = self.subRectH < 0 and 0 or self.subRectH;
	self.subMinPos = -self.subRectH / 2;
	self.subMaxPox = -self.subMinPos;
	self.scrollContainer:setScrollSize(0, self.subRectH);

	self:returnItem();
	local item;
	local lPosY = self.subRectH / 2 + 360;
	local cPosY = self.subRectH / 2 + 60;
	local rPosY = self.subRectH / 2 + 300;
	if self.adaptHeight < 0 then
		lPosY = lPosY + self.adaptHeight / 2;
		cPosY = cPosY + self.adaptHeight / 2;
		rPosY = rPosY + self.adaptHeight / 2;
	end
	local index;
	local vo;
	for i = 1, len do
		item = self:createItem();
		if i % 3 == 0 then
			item:setLocation(0, cPosY, 0);
			cPosY = cPosY - spaceVal;
		elseif i % 3 == 1 then
			item:setLocation(-160, lPosY, 0);
			lPosY = lPosY - spaceVal;
		else
			item:setLocation(160, rPosY, 0);
			rPosY = rPosY - spaceVal;
		end
		item:setData(arr[i]);

		if index == nil then
			vo = DataCenter.wildSecretData:getMineRegionVo(arr[i]);
			if vo.lockFlag == 1 then
				index = i;
			end
		end
	end
	self.curPosY = self.subRect.anchoredPosition.y;

	if self.isFirstEnter ~= false then
		self:moveToIndex(index);
	end
	self.isFirstEnter = false;

	self:updateDragItem();
end

function Lua_WildLodePanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_WildLodePanel", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_WildLodePanel:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_WildLodePanel:onTimer()
	local second = DataCenter.wildSecretData.mineSettleTick - DataCenter.roleData.serverTime;
	if second > 0 then
		self.timeText.text = LanUtil.formateStr(701002, Lua_TimeTransform.transSeconds18(second));
	else
		self:stopTimer();
		self.timeText.text = nil;
	end
end

function Lua_WildLodePanel:createItem()
	local len = self.hideList:getSize();
	local item;
	if len > 0 then
		item = self.hideList:remove();
		item:setEnable(true);
	else
		item = Lua_WildLodeItem.new(self.sub);
		item:setRectSize(281, 243);
	end
	self.showList:add(item);
	return item;
end

function Lua_WildLodePanel:returnItem()
	local len = self.showList:getSize();
	local item;
	while len > 0 do
		item = self.showList:remove(len);
		item:setEnable(false);
		self.hideList:add(item);
		len = len - 1;
	end
end

function Lua_WildLodePanel:updateDragItem()
	local subRectY = self.subRect.anchoredPosition.y;
	local len = self.showList:getSize();
	local item;
	for i = 1, len do
		item = self.showList[i];
		if item.y + subRectY > self.minY - 243 and item.y + subRectY < self.maxY + 243 then
			item:setEnable(true);
		else
			item:setEnable(false);
		end
	end
end

function Lua_WildLodePanel:moveToIndex(idx)
	idx = idx or 1;
	if idx <= 5 then
		self.targetPos = self.subMinPos;
	else
		self.targetPos = self.subMinPos + (idx - 5) * 243;
	end

	if self.targetPos > self.subMaxPox then
		self.targetPos = self.subMaxPox;
	elseif self.targetPos < self.subMinPos then
		self.targetPos = self.subMinPos;
	end

	self.scrollContainer:setScrollPosition(0, self.targetPos, 0);
end

function Lua_WildLodePanel:onCheckHelp(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { des = LanUtil.getValue(701001), posX = 170, posY = -280 });
end

function Lua_WildLodePanel:onCheckRank(go)
	Lua_WindowUtil.openWin("Lua_WildSecretRankWindow", Lua_WinParam.ACTION_OPEN, 2);
end

function Lua_WildLodePanel:onCheckRecord(go)
	self.recordRedPoint:clickHandler();
	Lua_WindowUtil.openWin("Lua_WildLodeRecordWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_WildLodePanel:onCheckReco(go)
	self.plunderRedPoint:clickHandler();
	Lua_WindowUtil.openWin("Lua_WildLodeRecommWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_WildLodePanel:onCheckLode(go)
	self.occupyRedPoint:clickHandler();
	Lua_WindowUtil.openWin("Lua_WildLodeSelfWindow", Lua_WinParam.ACTION_OPEN);
end










Lua_WildLodeItem = class("Lua_WildLodeItem", Lua_DisplayObject)
function Lua_WildLodeItem:ctor(p)
	self:superCall("ctor", p, "WildLodeItem_skin");
end

function Lua_WildLodeItem:buildShowItem()
	self:superCall("buildShowItem");
	self.avatarIcon:addClickFuntion(self, self.onCheckRole);
	self.btnCheck:addClickFuntion(self, self.onCheckRole);
end

function Lua_WildLodeItem:dispose()
	if self.uiEff then
		self.uiEff:dispose();
		self.uiEff = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildLodeItem:checkInBound(touchX, touchY)
	local minX = self.x - self.w / 2 * 0.9;
	local maxX = self.x + self.w / 2 * 0.9;
	local minY = self.y - self.h / 2 * 0.9;
	local maxY = self.y + self.h / 2 * 0.9;
	if touchX >= minX and touchX <= maxX and touchY >= minY and touchY <= maxY then
		return true
	end
	return false
end

function Lua_WildLodeItem:setData(data)
	self.data = data;
	local vo = DataCenter.wildSecretData:getMineRegionVo(data);
	self.bg:setAltas("wild_secret_icon", vo.bgSprite);
	self.nameText.text = vo.name;
	self.teamText.text = LanUtil.formateStr(701011, tostring(vo.teamNum));
	if vo.lockFlag == 1 then
		self.stateIcon:setEnable(false);
		self.lockIcon:setEnable(false);
		self.unlockText:setEnable(false);
	else
		self.stateIcon:setEnable(true);
		self.lockIcon:setEnable(true);
		self.unlockText:setEnable(true);
		self.unlockText.text = LanUtil.formateStr(701017, tostring(vo.floorId));
	end
	if vo.showRole and tonumber(vo.showRole.id) > 0 then
		self.avatarObject:SetActive(true);
		local avatarId = DataCenter.roleData:getDressUpId(Lua_DressUpDefine.MAINTYPE_HEAD, vo.showRole.dress_info);
		local avatarVo = DataCenter.roleUtil:getDressUpVoById(avatarId);
		self.avatarIcon:setAltas(avatarVo.atlas, avatarVo.sprite);
		self.numText.text = vo.roleNum;
	else
		self.avatarObject:SetActive(false);
	end
	self:showEff(vo.flag == 1);
end

function Lua_WildLodeItem:showEff(bValue)
	if bValue then
		if self.uiEff == nil then
			self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_mhmj_kg_01", "ui_mhmj_kg_01", -70, 45);
		end
		self.uiEff:setEnable(true);
	else
		if self.uiEff then
			self.uiEff:setEnable(false);
		end
	end
end

function Lua_WildLodeItem:onPressClick()
	local vo = DataCenter.wildSecretData:getMineRegionVo(self.data);
	if vo.lockFlag == 0 then
		OperateAlert.show(LanUtil.formateStr(701017, tostring(vo.floorId)));
		return;
	end
	DataCenter.wildSecretData.selectRegionId = self.data;
	Lua_WindowUtil.openWin("Lua_WildLodeWindow", Lua_WinParam.ACTION_OPEN, self.data);
end

function Lua_WildLodeItem:onCheckRole(go)
	Lua_WindowUtil.openWin("Lua_WildLodeFriendWindow", Lua_WinParam.ACTION_OPEN, self.data);
end