Lua_WildLodeRecommWindow = class("Lua_WildLodeRecommWindow", Lua_Window)
function Lua_WildLodeRecommWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_WildLodeRecommWindow";
	self.skinName = "WildLodeRecommWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_WildLodeRecommWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.btnRefresh:addClickFuntion(self, self.onRefreshClick);

	self:addLuaEvent("WILD_SECRET_LODE_RECOMM", self, self.updateServerInfo);
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeRecommInfo();
end

function Lua_WildLodeRecommWindow:dispose()
	self:stopTimer();
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_WildLodeRecommWindow:updateServerInfo(msg)
	self.timesText.text = LanUtil.formateStr(701016, tostring(DataCenter.wildSecretData.leftGrabTimes));

	self.last_refresh_tick = tonumber(msg.last_refresh_tick) + 3;
	local second = self.last_refresh_tick - DataCenter.roleData.serverTime;
	if second > 0 then
		self:startTimer();
		self:onTimer();
	else
		self:stopTimer();
		self.btnRefresh:setLangValue(303006);
		self.btnRefresh:setBtnEnable(true);
	end

	if msg.match_list == nil or #msg.match_list <= 0 then
		if self.recordList then
			self.recordList:setEnable(false);
		end
		self:showNone(true);
	else
		self:showNone(false);
		if self.itemList == nil then
			self.itemList = Lua_DragList.new(self.content, 630, 670, Lua_AxisDefine.Vertical);
			self.itemList:setLocation(0, -20.5, 0);
			self.itemList:setListCell(Lua_WildLodeRecommItem, 630, 147, 1);
			self.itemList:setCellSpacing(0, 5);
		end
		self.itemList:setEnable(true);
		table.sort( msg.match_list, function(a, b) return a.score > b.score end )
		self.itemList:setArrayData(msg.match_list);
	end
end

function Lua_WildLodeRecommWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_WildLodeRecommWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_WildLodeRecommWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_WildLodeRecommWindow:onTimer()
	local second = self.last_refresh_tick - DataCenter.roleData.serverTime;
	if second > 0 then
		self.btnRefresh.label = LanUtil.formateStr(701028, tostring(second));
		self.btnRefresh:setBtnEnable(false);
	else
		self:stopTimer();
		self.btnRefresh:setLangValue(303006);
		self.btnRefresh:setBtnEnable(true);
	end
end

function Lua_WildLodeRecommWindow:showNone(bValue)
	if bValue then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, -35, 0, 0);
			self.noneText = UICreate.createLabel(self.content, nil, 0, -66.5, 100, 40, 40);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
			self.noneText:setLangValue(701092);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end

function Lua_WildLodeRecommWindow:onRefreshClick(go)
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeRecommRefresh();
end










Lua_WildLodeRecommItem = class("Lua_WildLodeRecommItem", Lua_ListCell)
function Lua_WildLodeRecommItem:ctor(p)
	self:superCall("ctor", p, "WildLodeRecommItem_skin");
end

function Lua_WildLodeRecommItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.85, 0.85, 1);
	self.avatarItem:setLocation(-240, 0, 0);
	self.avatarItem:setCanClick(true);

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.7, 0.7, 1);
	self.itemIcon:setLocation(75, 0, 0);
	self.itemIcon:setCanClick(true);

	self.btnFight:addClickFuntion(self, self.onFightClick);
end

function Lua_WildLodeRecommItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildLodeRecommItem:setData(data)
	self.data = data;
	self.avatarItem:setRoleId(data.show_role.id, data.show_role.server_flag);
	self.avatarItem:setRoleDressUp(data.show_role.dress_info);
	self.avatarItem:setRoleLevel(data.show_role.level);
	self.nameText.text = data.show_role.name;
	self.serverText.text = LanUtil.formateStr(10047, data.show_role.server_prev);
	self.forceText.text = data.show_role.force;

	if self.rewardVo == nil then
		self.rewardVo = Lua_ToolVo.createToolVo(201000047);
	end
	self.rewardVo.count = data.score;
	self.itemIcon:setData(self.rewardVo);
end

function Lua_WildLodeRecommItem:onFightClick(go)
	if DataCenter.wildSecretData.leftGrabTimes <= 0 then
		OperateAlert.showLangValue(701026);
		return;
	end
	Lua_WindowUtil.openWin("Lua_WildLodeInfoWindow", Lua_WinParam.ACTION_OPEN, self.data.mine_site_id);
end