Lua_WildLodeRecordWindow = class("Lua_WildLodeRecordWindow", Lua_Window)
function Lua_WildLodeRecordWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_WildLodeRecordWindow";
	self.skinName = "WildLodeRecordWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_WildLodeRecordWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("WILD_SECRET_LODE_RECORD", self, self.updateServerInfo);

	self.tabInfo = Array();
	self.tabInfo:add(701018);
	self.tabInfo:add(701019);

	self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.buttonList:setLocation(0, -456.5, 0);
	self.buttonList:setButtonCell(Lua_CommonButtonItem2);
	self.buttonList:setButtonItem(160, 67);
	self.buttonList:setClickCallBack(self, self.onButtonClick);
	self.buttonList:setData(self.tabInfo);
	self.buttonList:setSelected(1);
end

function Lua_WildLodeRecordWindow:dispose()
	if self.buttonList then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	if self.tabInfo then
		self.tabInfo:clear();
		self.tabInfo = nil;
	end
	if self.recordList then
		self.recordList:dispose();
		self.recordList = nil;
	end
	self:superCall("dispose");
end

function Lua_WildLodeRecordWindow:onButtonClick(index, data)
	self.index = index;
	if index == 1 then
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeFightRecord();
	else
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeRevengeRecord();
	end
end

function Lua_WildLodeRecordWindow:updateServerInfo(msg)
	if msg.record_list == nil or #msg.record_list <= 0 then
		if self.recordList then
			self.recordList:setEnable(false);
		end
		self:showNone(true);
	else
		self:showNone(false);
		if self.recordList == nil then
			self.recordList = Lua_DragContainer.new(self.content, 628, 680, Lua_AxisDefine.Vertical);
			self.recordList:setLocation(0, -35, 0);
			self.recordList:setCellSpacing(0, 5);
		end
		self.recordList:setEnable(true);
		self.recordList:clearList();
		local itemClass = (self.index == 1) and Lua_WildLodeFightRecordItem or Lua_WildLodeRevengeRecordItem;
		for i = 1, #msg.record_list do
			self.recordList:addSubContainer(itemClass, msg.record_list[i]);
		end
		self.recordList:updateChildPos();
		self.recordList:moveToIndex(1, true);
	end
end

function Lua_WildLodeRecordWindow:showNone(bValue)
	if bValue then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, -35, 0, 0);
			self.noneText = UICreate.createLabel(self.content, nil, 0, -66.5, 100, 40, 40);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
			self.noneText:setLangValue(701020);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end










Lua_WildLodeFightRecordItem = class("Lua_WildLodeFightRecordItem", Lua_DragContainerItem)
function Lua_WildLodeFightRecordItem:ctor(p)
	self:superCall("ctor", p, "WildLodeFightRecordItem_skin");
end

function Lua_WildLodeFightRecordItem:buildShowItem()
	self:superCall("buildShowItem");
	self.checkPlay:addClickFuntion(self, self.onCheckPlay);
	self.checkRecord:addClickFuntion(self, self.onCheckRecord);
end

function Lua_WildLodeFightRecordItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildLodeFightRecordItem:getWidth()
	return 628;
end

function Lua_WildLodeFightRecordItem:getHeight()
	return 168;
end

function Lua_WildLodeFightRecordItem:setData(data)
	self.data = data;
	local str = os.date("%m/%d"..Lua_SpaceDefine.SPACE_TIME.."%H:%M", tonumber(data.fight_tick));
	if data.type == 1 then -- 占领
		self.recordText.text = LanUtil.formateStr(701022, str, tostring(data.args[1]), tostring(data.args[2]));
	elseif data.type == 2 then -- 掠夺
		self.recordText.text = LanUtil.formateStr(701024, str, tostring(data.args[1]), tostring(data.args[2]));
	elseif data.type == 3 then -- 被掠夺
		self.recordText.text = LanUtil.formateStr(701023, str, tostring(data.args[1]), tostring(data.args[2]));
	elseif data.type == 4 then -- 被占领
		self.recordText.text = LanUtil.formateStr(701021, str, tostring(data.args[1]));
	else
		self.recordText.text = str;
	end
end

function Lua_WildLodeFightRecordItem:onCheckPlay(go)
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.data.record_id, 0, nil, 0, 11);
end

function Lua_WildLodeFightRecordItem:onCheckRecord(go)
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightHurtCollect(self.data.record_id, 11);
end










Lua_WildLodeRevengeRecordItem = class("Lua_WildLodeRevengeRecordItem", Lua_DragContainerItem)
function Lua_WildLodeRevengeRecordItem:ctor(p)
	self:superCall("ctor", p, "WildLodeRevengeRecordItem_skin");
end

function Lua_WildLodeRevengeRecordItem:buildShowItem()
	self:superCall("buildShowItem");
	self.roleList = Array();

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-240, -22, 0);
	self.avatarItem:setCanClick(true);
end

function Lua_WildLodeRevengeRecordItem:dispose()
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.roleList then
		self.roleList:dispose();
		self.roleList:clear();
		self.roleList = nil;
	end
	self:superCall("dispose");
end

function Lua_WildLodeRevengeRecordItem:getWidth()
	return 628;
end

function Lua_WildLodeRevengeRecordItem:getHeight()
	return 168;
end

function Lua_WildLodeRevengeRecordItem:setData(data)
	self.avatarItem:setRoleId(data.show_role.id, data.show_role.server_flag);
	self.avatarItem:setRoleDressUp(data.show_role.dress_info);
	self.avatarItem:setRoleLevel(data.show_role.level);
	self.nameText.text = LanUtil.formateStr(10051, data.show_role.server_prev, data.show_role.name);
	self.forceText.text = data.show_role.force;
	if data.hatred_num > 0 then
		self.timesText.text = LanUtil.formateStr(701025, Lua_ColorDefine.getColorStr("5B8F3F", data.hatred_num));
	else
		self.timesText.text = LanUtil.formateStr(701025, Lua_ColorDefine.getColorStr("F84A41", data.hatred_num));
	end

	local item;
	for i = 1, 2 do
		item = self.roleList[i];
		if item == nil then
			item = Lua_WildLodeRevengeRoleItem.new(self.content);
			self.roleList:add(item);
		end
		item:setLocation(120 + (i - 1) * 130, 0, 0);
		item:setData(data.mite_site_info[i]);
	end
end








Lua_WildLodeRevengeRoleItem = class("Lua_WildLodeRevengeRoleItem", Lua_DisplayObject)
function Lua_WildLodeRevengeRoleItem:ctor(p)
	self:superCall("ctor", p, "WildLodeRevengeRoleItem_skin");
end

function Lua_WildLodeRevengeRoleItem:buildShowItem()
	self:superCall("buildShowItem");
	self.btnFight:addClickFuntion(self, self.onFightClick);
end

function Lua_WildLodeRevengeRoleItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildLodeRevengeRoleItem:setData(data)
	self.data = data;
	if data == nil or data.mine_site_id == 0 then
		self.noneIcon:setEnable(true);
		self.showObject:SetActive(false);
	else
		self.noneIcon:setEnable(false);
		self.showObject:SetActive(true);
		self.forceText.text = data.force;
		local config = DataCenter.wildSecretUtil:getLodePointConfig(data.mine_site_id);
		self.icon:setAltas("wild_secret_atlas", config.icon_sprite);
		self.nameText.text = LanUtil.formateStr(701029, tostring(config.region), tostring(config.map_id));
		if data.state == 1 then
			self.btnFight:setEnable(true);
			self.tipsLabel:setEnable(false);
		else
			self.btnFight:setEnable(false);
			self.tipsLabel:setEnable(true);
		end
	end
end

function Lua_WildLodeRevengeRoleItem:onFightClick(go)
	Lua_WindowUtil.openWin("Lua_WildLodeInfoWindow", Lua_WinParam.ACTION_OPEN, self.data.mine_site_id);
end