Lua_WildLodeReplaceWindow = class("Lua_WildLodeReplaceWindow", Lua_Window)
function Lua_WildLodeReplaceWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_WildLodeReplaceWindow";
	self.skinName = "WildLodeReplaceWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_WildLodeReplaceWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.desText:setLangValue(701084);

	self.itemList = Lua_DragList.new(self.content, 627, 526, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, 1, 0);
	self.itemList:setListCell(Lua_WildLodeReplaceItem, 627, 172, 1);
	self.itemList:setCellSpacing(0, 5);

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);

	self:addLuaEvent("WILD_SECRET_LODE_SELF", self, self.updateServerInfo);
	self:onRequestInfo();
end

function Lua_WildLodeReplaceWindow:dispose()
	Lua_CommonUtil.removeTimer(self, self.onRequestInfo);
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_WildLodeReplaceWindow:onRequestInfo()
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeSelfInfo();
end

function Lua_WildLodeReplaceWindow:updateServerInfo(msg)
	Lua_CommonUtil.removeTimer(self, self.onRequestInfo);
	local info;
	local sec = 86400;
	for i = 1, #msg.mite_site_list do
		info = msg.mite_site_list[i];
		if info.mine_site_id > 0 then
			local temp = tonumber(info.protect_end_tick) - DataCenter.roleData.serverTime;
			if temp > 0 and temp < sec then
				sec = temp;
			end
		end
	end
	if sec > 0 and sec ~= 86400 then
		Lua_CommonUtil.delayCall(sec, self, self.onRequestInfo);
	end

	table.sort(msg.mite_site_list, function(a, b) return a.num < b.num end);
	self.itemList:setArrayData(msg.mite_site_list);
	self.itemList.canDrag = not self.itemList.isTheEnd;
end

function Lua_WildLodeReplaceWindow:onCheckHelp(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { des = LanUtil.getValue(701030), needAdapt = false, posX = -30, posY = 180 });
end










Lua_WildLodeReplaceItem = class("Lua_WildLodeReplaceItem", Lua_ListCell)
function Lua_WildLodeReplaceItem:ctor(p)
	self:superCall("ctor", p, "WildLodeReplaceItem_skin");
end

function Lua_WildLodeReplaceItem:buildShowItem()
	self:superCall("buildShowItem");
	self.btnReplace:addClickFuntion(self, self.onReplaceClick);
end

function Lua_WildLodeReplaceItem:dispose()
	self:stopTimer();
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildLodeReplaceItem:setData(data)
	self.data = data;
	self.left_output_tick = data.left_output_tick;
	self.bProtect = false;

	if data.mine_site_id > 0 then
		self.showObject:SetActive(true);
		self.developTimeText:setEnable(false);
		self.noneBg:setEnable(false);
		self.noneLabel:setEnable(false);

		local config = DataCenter.wildSecretUtil:getLodePointConfig(data.mine_site_id);
		self.icon:setAltas("wild_secret_icon", config.bg_sprite);

		if data.lucky_bonus > 0 then
			self.luckBg:setEnable(true);
			self.luckValueText:setEnable(true);
			self.luckValueText.text = LanUtil.formateStr(701034, tostring(data.lucky_bonus));
		else
			self.luckBg:setEnable(false);
			self.luckValueText:setEnable(false);
		end
		self.forceText.text = tonumber(data.force);
		self.nameText.text = config.name;
		-- if data.floor_per_hour_profit > 0 then
		-- 	self.incomeText.text = LanUtil.formateStr(701036, tostring(data.per_hour_profit), tostring(data.floor_per_hour_profit));
		-- else
		-- 	self.incomeText.text = LanUtil.formateStr(701073, tostring(data.per_hour_profit));
		-- end
		self.incomeText.text = LanUtil.formateStr(701073, tostring(data.per_hour_profit + data.floor_per_hour_profit));
		self.incomeCount.text = data.total_profit;
	else
		self.showObject:SetActive(false);
		self.developTimeText:setEnable(true);
		self.developTimeText.text = LanUtil.formateStr(701032, Lua_TimeTransform.transSeconds6(self.left_output_tick));
		self.noneBg:setEnable(true);
		self.noneLabel:setEnable(true);
		self.icon:setAltas("wild_secret_icon", "xui_mhyj_widget_24");
	end

	self:startTimer();
	self:onTimer();
end

function Lua_WildLodeReplaceItem:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_WildLodeReplaceItem", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_WildLodeReplaceItem:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_WildLodeReplaceItem:onTimer()
	if self.data.mine_site_id > 0 then
		self.left_output_tick = self.left_output_tick - 1;
		if self.left_output_tick > 0 then
			self.gatherTimeText.text = LanUtil.formateStr(701031, Lua_TimeTransform.transSeconds6(self.left_output_tick));
		else
			self.gatherTimeText.text = LanUtil.formateStr(701031, Lua_TimeTransform.transSeconds6(0));
		end

		local second = tonumber(self.data.protect_end_tick) - DataCenter.roleData.serverTime;
		if second > 0 then
			self.bProtect = true;
			self.btnReplace:setEnable(false);
			self.protectText:setEnable(true);
			self.protectText.text = LanUtil.formateStr(701033, Lua_TimeTransform.transSeconds6(second));
		else
			self.bProtect = false;
			self.btnReplace:setEnable(true);
			self.protectText:setEnable(false);
		end

		if self.left_output_tick <= 0 and second <= 0 then
			self:stopTimer();
		end
	else
		self:stopTimer();
	end
end

function Lua_WildLodeReplaceItem:onReplaceClick(go)
	Lua_MsgUtil.callFunc("WILD_SECRET_LODE_REPLACE_CLICK", self.data.num);
	Lua_WindowUtil.openWin("Lua_WildLodeReplaceWindow", Lua_WinParam.ACTION_CLOSE);
end