Lua_WildLodeSelfWindow = class("Lua_WildLodeSelfWindow", Lua_Window)
function Lua_WildLodeSelfWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_WildLodeSelfWindow";
	self.skinName = "WildLodeSelfWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_WildLodeSelfWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 627, 526, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, 1, 0);
	self.itemList:setListCell(Lua_WildLodeSelfItem, 627, 172, 1);
	self.itemList:setCellSpacing(0, 5);

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);

	self:addLuaEvent("WILD_SECRET_LODE_GIVEUP", self, self.onRequestInfo);
	self:addLuaEvent("WILD_SECRET_LODE_SELF", self, self.updateServerInfo);
	self:addLuaEvent("WILD_SECRET_LODE_DEFEND_LINEUP", self, self.onDefendLineup);
	self:onRequestInfo();
end

function Lua_WildLodeSelfWindow:dispose()
	Lua_CommonUtil.removeTimer(self, self.onRequestInfo);
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_WildLodeSelfWindow:onRequestInfo()
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeSelfInfo();
end

function Lua_WildLodeSelfWindow:updateServerInfo(msg)
	Lua_CommonUtil.removeTimer(self, self.onRequestInfo);
	local info;
	local sec = 86400;
	for i = 1, #msg.mite_site_list do
		info = msg.mite_site_list[i];
		if info.mine_site_id > 0 then
			local temp = tonumber(info.protect_end_tick) - DataCenter.roleData.serverTime;
			if temp > 0 and temp < sec then
				sec = temp;
			end
		end
	end
	if sec > 0 and sec ~= 86400 then
		Lua_CommonUtil.delayCall(sec, self, self.onRequestInfo);
	end

	table.sort(msg.mite_site_list, function(a, b) return a.num < b.num end);
	self.itemList:setArrayData(msg.mite_site_list);
	self.itemList.canDrag = not self.itemList.isTheEnd;
end

function Lua_WildLodeSelfWindow:onDefendLineup(data)
	local sceneId = DataCenter.wildSecretData:getLodeFightSceneId(data.mine_site_id);
	DataCenter.preLoadData:preShowScene("Lua_WildLodeDefendLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, data, sceneId, 0);
end

function Lua_WildLodeSelfWindow:onSceneShow(param, mp, success)
	if not success then return; end
	local config = DataCenter.wildSecretUtil:getLodePointConfig(param.mine_site_id);
	config = Lua_MonsterPlayerConfigData.getConfigData(config.monster_id);
	param = { lineup_type = 48 + param.num, stage_id = param.mine_site_id, team_num = #config.fighter_list };
	Lua_WindowUtil.openWin("Lua_WildLodeDefendLineupWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_WildLodeSelfWindow:onCheckHelp(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { des = LanUtil.getValue(701030), needAdapt = false, posX = -30, posY = 180 });
end










Lua_WildLodeSelfItem = class("Lua_WildLodeSelfItem", Lua_ListCell)
function Lua_WildLodeSelfItem:ctor(p)
	self:superCall("ctor", p, "WildLodeSelfItem_skin");
end

function Lua_WildLodeSelfItem:buildShowItem()
	self:superCall("buildShowItem");
	self.btnLineup:addClickFuntion(self, self.onLineupClick);
	self.btnGiveUp:addClickFuntion(self, self.onGiveUpClick);
end

function Lua_WildLodeSelfItem:dispose()
	self:stopTimer();
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildLodeSelfItem:setData(data)
	self.data = data;
	self.left_output_tick = data.left_output_tick;
	self.bProtect = false;

	if data.mine_site_id > 0 then
		self.showObject:SetActive(true);
		self.developTimeText:setEnable(false);
		self.noneBg:setEnable(false);
		self.noneLabel:setEnable(false);

		local config = DataCenter.wildSecretUtil:getLodePointConfig(data.mine_site_id);
		self.icon:setAltas("wild_secret_icon", config.bg_sprite);

		if data.lucky_bonus > 0 then
			self.luckBg:setEnable(true);
			self.luckValueText:setEnable(true);
			self.luckValueText.text = LanUtil.formateStr(701034, tostring(data.lucky_bonus));
		else
			self.luckBg:setEnable(false);
			self.luckValueText:setEnable(false);
		end
		self.forceText.text = tonumber(data.force);
		self.nameText.text = config.name;
		-- if data.floor_per_hour_profit > 0 then
		-- 	self.incomeText.text = LanUtil.formateStr(701036, tostring(data.per_hour_profit), tostring(data.floor_per_hour_profit));
		-- else
		-- 	self.incomeText.text = LanUtil.formateStr(701073, tostring(data.per_hour_profit));
		-- end
		self.incomeText.text = LanUtil.formateStr(701073, tostring(data.per_hour_profit + data.floor_per_hour_profit));
		self.incomeCount.text = data.total_profit;
	else
		self.showObject:SetActive(false);
		self.developTimeText:setEnable(true);
		self.developTimeText.text = LanUtil.formateStr(701032, Lua_TimeTransform.transSeconds6(self.left_output_tick));
		self.noneBg:setEnable(true);
		self.noneLabel:setEnable(true);
		self.icon:setAltas("wild_secret_icon", "xui_mhyj_widget_24");
	end

	self:startTimer();
	self:onTimer();
end

function Lua_WildLodeSelfItem:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_WildLodeSelfItem", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_WildLodeSelfItem:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_WildLodeSelfItem:onTimer()
	if self.data.mine_site_id > 0 then
		self.left_output_tick = self.left_output_tick - 1;
		if self.left_output_tick > 0 then
			self.gatherTimeText.text = LanUtil.formateStr(701031, Lua_TimeTransform.transSeconds6(self.left_output_tick));
		else
			self.gatherTimeText.text = LanUtil.formateStr(701031, Lua_TimeTransform.transSeconds6(0));
		end

		local second = tonumber(self.data.protect_end_tick) - DataCenter.roleData.serverTime;
		if second > 0 then
			self.bProtect = true;
			self.btnLineup:setEnable(false);
			self.btnGiveUp:setEnable(false);
			self.protectText:setEnable(true);
			self.protectText.text = LanUtil.formateStr(701033, Lua_TimeTransform.transSeconds6(second));
		else
			self.bProtect = false;
			self.btnLineup:setEnable(true);
			self.btnGiveUp:setEnable(true);
			self.protectText:setEnable(false);
		end

		if self.left_output_tick <= 0 and second <= 0 then
			self:stopTimer();
		end
	else
		self:stopTimer();
	end
end

function Lua_WildLodeSelfItem:onLineupClick(go)
	local restTick = DataCenter.wildSecretUtil.restTick;
	if restTick then
		local hour = tonumber(os.date("%H", DataCenter.roleData.serverTime));
		if hour >= restTick[1] and hour < restTick[2] then
			OperateAlert.showLangValue(701057);
			return;
		end
	end

	if self.bProtect then
		OperateAlert.showLangValue(701081);
	else
		Lua_MsgUtil.callFunc("WILD_SECRET_LODE_DEFEND_LINEUP", self.data);
	end
end

function Lua_WildLodeSelfItem:onGiveUpClick(go)
	local restTick = DataCenter.wildSecretUtil.restTick;
	if restTick then
		local hour = tonumber(os.date("%H", DataCenter.roleData.serverTime));
		if hour >= restTick[1] and hour < restTick[2] then
			OperateAlert.showLangValue(701057);
			return;
		end
	end
	
	if self.bProtect then
		OperateAlert.showLangValue(701080);
	else
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, { des = 701037, btnType = 1, owner = self, sureFun = self.onGiveUp });
	end
end

function Lua_WildLodeSelfItem:onGiveUp()
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeGiveUp(self.data.num);
end