-- 矿脉界面
Lua_WildLodeWindow = class("Lua_WildLodeWindow", Lua_Window)
function Lua_WildLodeWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.MAIN_MENU_LAYER;
	self.windowName = "Lua_WildLodeWindow";
	self.skinName = "WildLodeWindow_skin";
	self.isFullPaving = true;
	self.isFullSizeWin = true;
	self.showWinBg = true;
	local id = DataCenter.wildSecretData.selectRegionId;
	local vo = DataCenter.wildSecretData:getMineRegionVo(id);
	self.winBgPath = vo.bgPath;
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_WildLodeWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.winBg.anchorValue = 4;
	self.winBg.pivotValue = 4;
	self.bShowLuck = false;
	self.bRetract = false;
	self.retractTime = 10;
	
	self:addLuaEvent("FIGHTPLAY_COMPLETE", self, self.onFightPlayCompleted);
	self:addLuaEvent("WILD_SECRET_LODE_GIVEUP", self, self.onRequestInfo);
	self:addLuaEvent("WILD_SECRET_LODE_POINT", self, self.updateServerInfo);
	self:addLuaEvent("WILD_SECRET_LODE_POINT_SELECT", self, self.onPointSelected);
	self:addLuaEvent("WILD_SECRET_LODE_MAP_SELECT", self, self.onMapSelected);

	self.mapArr = Array();
	self.pointArr = Array();

	self.recordRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.WildSecret_Lode_Record);
	self.recordRedPoint:setRectAnchor(1);
	self.recordRedPoint:setLocation(325, -300);

	self.occupyRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.WildSecret_Lode_Occupy);
	self.occupyRedPoint:setRectAnchor(7);
	self.occupyRedPoint:setLocation(315, 210);
	
	self.plunderRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.WildSecret_Lode_Plunder);
	self.plunderRedPoint:setRectAnchor(7);
	self.plunderRedPoint:setLocation(315, 328);

	self.luckValueText.text = LanUtil.formateStr(701039, tostring(DataCenter.wildSecretUtil.luckValue));
	self.luckText:setLangValue(701095);
	self.btnRetract:addClickFuntion(self, self.onRetractLuck);
	self.btnLuck:addClickFuntion(self, self.onCheckLuck);
	self.btnHelp:addClickFuntion(self, self.onCheckHelp);
	self.btnRank:addClickFuntion(self, self.onCheckRank);
	self.btnRecord:addClickFuntion(self, self.onCheckRecord);
	self.btnRegion:addClickFuntion(self, self.onCheckRegion);
	self.btnReco:addClickFuntion(self, self.onCheckReco);
	self.btnLode:addClickFuntion(self, self.onCheckLode);
	self.btnDetails:addClickFuntion(self, self.onCheckDetails);
	self.leftArrow:addClickFuntion(self, self.onLeftClick);
	self.rightArrow:addClickFuntion(self, self.onRightClick);
end

function Lua_WildLodeWindow:dispose()
	self:stopTimer();
	if self.luckObject then
		TweenUtil.getInstance():stop(self.luckObject);
	end
	if self.pointArr then
		self.pointArr:dispose();
		self.pointArr:clear();
		self.pointArr = nil;
	end
	if self.mapList then
		self.mapList:dispose();
		self.mapList = nil;
	end
	if self.mapArr then
		self.mapArr:clear();
		self.mapArr = nil;
	end
	if self.recordRedPoint then
		self.recordRedPoint:dispose();
		self.recordRedPoint = nil;
	end
	if self.occupyRedPoint then
		self.occupyRedPoint:dispose();
		self.occupyRedPoint = nil;
	end
	if self.plunderRedPoint then
		self.plunderRedPoint:dispose();
		self.plunderRedPoint = nil;
	end
	self:superCall("dispose");
end

function Lua_WildLodeWindow:showWin(param)
	self:superCall("showWin", param);
	self:updateShowInfo();
end

function Lua_WildLodeWindow:onBackBtnClick(go)
	self:superCall("onBackBtnClick", go);
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeRegionInfo();
end

function Lua_WildLodeWindow:updateShowInfo()
	self.mapArr:clear();
	local vo = DataCenter.wildSecretData:getMineRegionVo(self.showData);
	for i = 1, vo.mapNum do
		self.mapArr:add(i);
	end
	local width = 55 * 5;
	if vo.mapNum < 5 then
		width = 55 * vo.mapNum;
	end
	if self.mapList == nil then
		self.mapList = Lua_DragList.new(self.content, width, 55, Lua_AxisDefine.Horizontal);
		self.mapList:setRectAnchor(7);
		self.mapList:setLocation(0, 152, 0);
		self.mapList:setListCell(Lua_WildLodeMapCell, 55, 55, 1);
	end
	self.mapList:setArrayData(self.mapArr);
	self.mapList.canDrag = not self.mapList.isTheEnd;
	self.mapList:moveToIndex(1, true);
	self.mapList:setSelected(1);
	self.mapList:setSelectClick(1);

	width = width / 2;
	self.leftArrow:setLocation(-width - 6.5, 152, 0);
	self.rightArrow:setLocation(width + 6.5, 152, 0);
end

function Lua_WildLodeWindow:onFightPlayCompleted(templateId)
	if templateId == 1045 or templateId == 1046 then
		self:onRequestInfo();
	end
end

function Lua_WildLodeWindow:updateServerInfo()
	self.plunderText.text = LanUtil.formateStr(701016, tostring(DataCenter.wildSecretData.leftGrabTimes));
	self.benefitText.text = LanUtil.formateStr(701040, tostring(DataCenter.wildSecretData.totalProfit));
	self.benefitText:resetSize();
	self.btnDetails:setLocation(self.benefitText.width / 2 + 20, 213, 0);

	local mineInfo = DataCenter.wildSecretData.mineInfo;
	self.bShowLuck = false;
	if mineInfo then
		local vo = DataCenter.wildSecretData:getMineRegionVo(self.showData);
		local len = #vo.pointPos;
		local value = self.mapId % len;
		value = value == 0 and len or value;
		local list = vo.pointPos[value];
		local item;
		for i = 1, #mineInfo do
			item = self.pointArr[i];
			if item == nil then
				item = Lua_WildLodePointItem.new(self.pointObject);
				self.pointArr:add(item);
			else
				item:setEnable(true);
			end
			if #list >= i then
				item:setLocation(list[i][1], list[i][2], 0);
			else
				item:setLocation(0, 0, 0);
			end
			item:setData(mineInfo[i]);
			if mineInfo[i].lucky_bonus > 0 then
				self.bShowLuck = true;
			end
		end
	else
		for i = 1, self.pointArr:getSize() do
			self.pointArr[i]:setEnable(false);
		end
	end
	self.luckObject:SetActive(self.bShowLuck);
	self.btnLuck:setEnable(self.bShowLuck and self.bRetract);
	self.retractTime = 10;

	self:startTimer();
	self:onTimer();
end

function Lua_WildLodeWindow:onPointSelected(pointId)
	Lua_WindowUtil.openWin("Lua_WildLodeInfoWindow", Lua_WinParam.ACTION_OPEN, pointId);
	self:onRequestInfo();
end

function Lua_WildLodeWindow:onMapSelected(mapId)
	if self.mapId == mapId then
		return;
	end
	self.mapId = mapId;
	self.mapList:moveToIndex(mapId, true);
	self.mapList:setSelected(mapId);
	self:onRequestInfo();
end

function Lua_WildLodeWindow:onRequestInfo()
	self.calcSec = 0;
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodePointInfo(self.showData, self.mapId);
end

function Lua_WildLodeWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_WildLodeWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_WildLodeWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_WildLodeWindow:onTimer()
	local second = DataCenter.wildSecretData.mineSettleTick - DataCenter.roleData.serverTime;
	if second > 0 then
		self.timeText.text = LanUtil.formateStr(701002, Lua_TimeTransform.transSeconds18(second));
	else
		self.timeText.text = nil;
	end

	if self.bShowLuck and not self.bRetract then
		self.retractTime = self.retractTime - 1;
		if self.retractTime <= 0 then
			self:onRetractLuck();
		end
	end

	self.calcSec = self.calcSec + 1;
	if self.calcSec == 60 then
		self:onRequestInfo();
	end
end

function Lua_WildLodeWindow:onRetractLuck(go)
	self.bRetract = true;
	TweenUtil.getInstance():stop(self.luckObject);
	TweenUtil.getInstance():addTweenTargetPos(self.luckObject, 0.3, 0, -360, 0, 0, self, self.onTweenCompleted);
end

function Lua_WildLodeWindow:onCheckLuck(go)
	self.bRetract = false;
	self.retractTime = 10;
	self.btnLuck:setEnable(false);
	TweenUtil.getInstance():stop(self.luckObject);
	TweenUtil.getInstance():addTweenTargetPos(self.luckObject, 0.3, 0, 0, 0, 0, self, self.onTweenCompleted);
end

function Lua_WildLodeWindow:onTweenCompleted()
	if self.bRetract then
		self.btnLuck:setEnable(true);
	else
		self.btnLuck:setEnable(false);
	end
end

function Lua_WildLodeWindow:onCheckHelp(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { des = LanUtil.getValue(701038), posX = 170, posY = -280 });
end

function Lua_WildLodeWindow:onCheckRank(go)
	Lua_WindowUtil.openWin("Lua_WildSecretRankWindow", Lua_WinParam.ACTION_OPEN, 2);
end

function Lua_WildLodeWindow:onCheckRecord(go)
	self.recordRedPoint:clickHandler();
	Lua_WindowUtil.openWin("Lua_WildLodeRecordWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_WildLodeWindow:onCheckRegion(go)
	Lua_WindowUtil.openWin("Lua_WildLodeMapWindow", Lua_WinParam.ACTION_OPEN, self.showData);
end

function Lua_WildLodeWindow:onCheckReco(go)
	self.plunderRedPoint:clickHandler();
	Lua_WindowUtil.openWin("Lua_WildLodeRecommWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_WildLodeWindow:onCheckLode(go)
	self.occupyRedPoint:clickHandler();
	Lua_WindowUtil.openWin("Lua_WildLodeSelfWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_WildLodeWindow:onCheckDetails(go)
	Lua_WindowUtil.openWin("Lua_WildLodeIncomeInfoWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_WildLodeWindow:onLeftClick(go)
	if self.mapId <= 1 then
		return;
	end
	self.mapId = self.mapId - 1;
	self.mapList:moveToIndex(self.mapId, true);
	self.mapList:setSelected(self.mapId);
	self:onRequestInfo();
end

function Lua_WildLodeWindow:onRightClick(go)
	if self.mapId >= self.mapArr:getSize() then
		return;
	end
	self.mapId = self.mapId + 1;
	self.mapList:moveToIndex(self.mapId, true);
	self.mapList:setSelected(self.mapId);
	self:onRequestInfo();
end










Lua_WildLodePointItem = class("Lua_WildLodePointItem", Lua_DisplayObject)
function Lua_WildLodePointItem:ctor(p)
	self:superCall("ctor", p, "WildLodePointItem_skin");
end

function Lua_WildLodePointItem:buildShowItem()
	self:superCall("buildShowItem");

	self.uiEff = UICreate.createUIEffect(self.content, nil, nil, 9, -40);
	self.uiEff.siblingIndex = 0;
	self.bg:addClickFuntion(self, self.onClick);
end

function Lua_WildLodePointItem:dispose()
	self:stopTimer();
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.uiEff then
		self.uiEff:dispose();
		self.uiEff = nil;
	end
	if self.luckEff then
		self.luckEff:dispose();
		self.luckEff = nil;
	end
	self.data = data;
	self:superCall("dispose");
end

function Lua_WildLodePointItem:setData(data)
	self.data = data;
	local config = DataCenter.wildSecretUtil:getLodePointConfig(data.region_id);
	self.uiEff:setUrl("/effects/uiEffects/"..config.effect, config.effect);
	self:showLuckEff(data.lucky_bonus > 0);
	if data.status == 1 then
		self.uiEff:setSpineAniState(0, "wait2");
		self.nameText:setLangValue(701043);
		self.nameText.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
		self.showObject:SetActive(false);
		self:stopTimer();
	else
		self.uiEff:setSpineAniState(0, "wait");
		self.showObject:SetActive(true);
		self.nameText.text = data.show_role.name;
		if DataCenter.roleData:isMyself(data.show_role.id) then
			self.nameText.colorStr = Lua_ColorDefine.transColorStr("8FD7FF");
		else
			self.nameText.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
		end
		self.protectLabel:setEnable(data.status == 2);

		self.forceText.text = LanUtil.formateStr(701044, tostring(data.show_role.force));
		self.outputBar:setMaxValue(100);
		self.outputBar:setValue(data.occupy_process);
		self.outputBar:setText(data.total_profit);

		if self.avatarItem == nil then
			self.avatarItem = Lua_AvatarItem.new(self.showObject);
			self.avatarItem:setScale(0.58, 0.58, 1);
			self.avatarItem:setLocation(-105, 70.5, 0);
			self.avatarItem:setCanClick(true);
		end
		self.avatarItem:setRoleId(data.show_role.id, data.show_role.server_flag);
		self.avatarItem:setRoleDressUp(data.show_role.dress_info);
		self.avatarItem:setRoleLevel(data.show_role.level);

		self.left_output_tick = tonumber(data.left_output_tick);
		self:startTimer();
		self:onTimer();
	end
end

function Lua_WildLodePointItem:showLuckEff(bValue)
	if bValue then
		if self.luckEff == nil then
			self.luckEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_mhmj_xykd_01_1", "ui_mhmj_xykd_01_1", 0, 0);
		end
		self.luckEff:setEnable(true);
	else
		if self.luckEff then
			self.luckEff:setEnable(false);
		end
	end
end

function Lua_WildLodePointItem:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_WildLodePointItem", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_WildLodePointItem:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_WildLodePointItem:onTimer()
	self.left_output_tick = self.left_output_tick - 1;
	if self.left_output_tick > 0 then
		self.timeText.text = Lua_TimeTransform.transSeconds6(self.left_output_tick);
	else
		self:stopTimer();
		self.timeText.text = nil;
	end
end

function Lua_WildLodePointItem:onClick(go)
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("WILD_SECRET_LODE_POINT_SELECT", self.data.region_id);
end










Lua_WildLodeMapCell = class("Lua_WildLodeMapCell", Lua_ListCell)
function Lua_WildLodeMapCell:ctor(p)
	self:superCall("ctor", p, "WildLodeMapCell_skin");
end

function Lua_WildLodeMapCell:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_WildLodeMapCell:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildLodeMapCell:setData(data)
	self.data = data;
	self.numText.text = data;
end

function Lua_WildLodeMapCell:onSelectionChange(bSelected)
	self:superCall("onSelectionChange", bSelected);
	if bSelected then
		self.bg:setAltas("wild_secret_atlas", "xui_mhyj_btn_1_p");
	else
		self.bg:setAltas("wild_secret_atlas", "xui_mhyj_btn_1_n");
	end
end

function Lua_WildLodeMapCell:onPressClick()
	Lua_MsgUtil.callFunc("WILD_SECRET_LODE_MAP_SELECT", self.data);
	return true;
end