Lua_WildStageList = class("Lua_WildStageList", Lua_DisplayObject)
function Lua_WildStageList:ctor(p, width, height)
	self.rectWidth = width;
	self.rectHeight = height;

	self.minX = -width / 2;
	self.maxX = width / 2;
	self.minY = -height / 2;
	self.maxY = height / 2;

	self.targetPosY = -50;
	self.cellSpacingX = 0;
	self.cellSpacingY = 0;
	self.blockSizeX = 0;
	self.blockSizeY = 0;

	self.showList = Array();
	self.hideList = Array();
	self.selectIdx = 1;
	self.alphaChange = 0.45;
	self.moveSpd = 100;
	self._moveTime = 0.3;

	self:superCall("ctor", p);
end

function Lua_WildStageList:buildShowItem()
	self:superCall("buildShowItem");
	self:setRectSize(self.rectWidth, self.rectHeight);

	self.maskContainer = UICreate.createUIMaskContainer(self.content, nil, nil, 0, 0, 0, 0);
	self.maskContainer:setAnchorMin(0, 0);
	self.maskContainer:setAnchorMax(1, 1);
	self.maskContainer:addImage();
	self.maskContainer:addRectMask2D();
	self.maskContainer:setSubRectPivot(0.5, 0.5);
	self.maskContainer:setColor(0, 0, 0, 1);
	self.maskContainer.clickScale = false;
	self.maskContainer:addMousDownFuntion(self, self.onMouseDownFun);
	self.maskContainer:addMouseUpFuntion(self, self.onMouseUpFun);
end

function Lua_WildStageList:dispose()
	self:stopTimer();
	local len;
	local item;
	if self.showList then
		len = self.showList:getSize();
		while len > 0 do
			item = self.showList:remove();
			TweenUtil.getInstance():stop(item.content, true);
			item:dispose();
			item = nil;
			len = len - 1;
		end
		self.showList:dispose();
		self.showList:clear();
		self.showList = nil;
	end
	if self.hideList then
		len = self.hideList:getSize();
		while len > 0 do
			item = self.hideList:remove();
			TweenUtil.getInstance():stop(item.content, true);
			item:dispose();
			item = nil;
			len = len - 1;
		end
		self.hideList:dispose();
		self.hideList:clear();
		self.hideList = nil;
	end
	if self.maskContainer then
		self.maskContainer:dispose();
		self.maskContainer = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildStageList.Set:moveTime(value)
	self._moveTime = value or 0.3;
end

function Lua_WildStageList:setContentRect(width, height)
	self.rectWidth = width;
	self.rectHeight = height;
	self:setRectSize(width, height);
end

function Lua_WildStageList:setListCell(cellClass, cellWidth, cellHeight)
	self.cellClass = cellClass;
	self.cellWidth = cellWidth;
	self.cellHeight = cellHeight;
	self.blockSizeX = cellWidth + self.cellSpacingX;
	self.blockSizeY = cellWidth + self.cellSpacingY;
	-- self.targetPosY = cellHeight / 2 - self.rectHeight / 2;
end

function Lua_WildStageList:setCellSpacing(spacingX, spacingY)
	self.cellSpacingX = spacingX;
	self.cellSpacingY = spacingY;
	self.blockSizeX = self.cellWidth + spacingX;
	self.blockSizeY = self.cellHeight + spacingY;
end

function Lua_WildStageList:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	if data.typeof ~= nil and data:typeof() == type_str_array then
		self.cellCount = data:getSize();
	else
		self.cellCount = #data;
	end
	self:initItem();
end

function Lua_WildStageList:moveToIndex(idx, immediately)
	if self.cellCount <= 0 then
		return;
	end

	idx = idx or 1;
	idx = idx < 1 and 1 or idx;
	idx = idx > self.cellCount and self.cellCount or idx;
	if idx == self.selectIdx then
		return;
	end
	
	if immediately == true then
		self.selectIdx = idx;
		self:initItem();
	else
		self:updateItemPos(idx, false);
	end
end

function Lua_WildStageList:initItem()
	self:returnCells();

	local value = self.selectIdx;
	value = value < 1 and 1 or value;
	value = value > self.cellCount and self.cellCount or value;
	local item = self:getCellFromPool();
	item:setScale(1, 1, 1);
	item:setLocation(0, self.targetPosY, 0);
	item:setItemIdx(value);
	item:setAlpha(1);
	item:setData(self.data[value]);
	item:setState(true);

	local num = 0;
	local itemY = item.itemY;
	while (itemY + self.blockSizeY / 2) < (self.rectHeight / 2) do
		num = num + 1;
		value = value + 1;
		if value > self.cellCount then
			break;
		else
			itemY = itemY + self.blockSizeY;
			item = self:getCellFromPool();
			item:setSiblingIndex(0);
			item:setScale(1 - num * 0.2, 1 - num * 0.2, 1);
			item:setLocation(0, itemY, 0);
			item:setItemIdx(value);
			item:setAlpha(1 - num * self.alphaChange);
			item:setData(self.data[value]);
			item:setState(false);
		end
	end
end

function Lua_WildStageList:getCellFromPool()
	local item;
	if self.hideList:getSize() > 0 then
		item = self.hideList:remove();
		item:setEnable(true);
	else
		item = self.cellClass.new(self.maskContainer.mainContent);
		item:setRectSize(self.cellWidth, self.cellHeight);
	end
	self.showList:add(item);
	return item;
end

function Lua_WildStageList:returnCellToPool(item)
	if item == nil then
		return;
	end
	TweenUtil.getInstance():stop(item.content);
	item:setEnable(false);
	self.hideList:add(item);
end

function Lua_WildStageList:returnCells()
	local len = self.showList:getSize();
	local item;
	while len > 0 do
		item = self.showList:remove(len);
		TweenUtil.getInstance():stop(item.content);
		item:setEnable(false);
		self.hideList:add(item);
		len = len - 1;
	end
end

function Lua_WildStageList:onMouseDownFun(go)
	self.startClickPos = self.mousePosition;
	self.startClickTime = getTime();
end

function Lua_WildStageList:onMouseUpFun(go)
	local dis = self.mousePosition - self.startClickPos;
	local isAdd = true;
	local moveIdx = 0;
	if getTime() - self.startClickTime <= 0.3 and Mathf.Abs(dis) < 100 then
		self.maskContainer:refreshTouchPosInverseSubTf();
		local posX = self.maskContainer.touchSubRectPx;
		local posY = self.maskContainer.touchSubRectPy;
		self.showList:sort("itemIdx", false);
		local len = self.showList:getSize();
		for i = 1, len do
			if self.showList[i]:checkInBound(posX, posY) and self.showList[i].itemIdx == self.selectIdx then
				self.showList[i]:onPressClick();
				break;
			end
		end
	else
		if self.bTimer then
			return;
		end

		local item = self:getItemByIdx(self.selectIdx);
		if item ~= nil then
			if dis > 0 then
				isAdd = true;
				moveIdx = item.itemIdx - 1;
			else
				isAdd = false;
				moveIdx = item.itemIdx + 1;
			end
		end		
	end

	if moveIdx > 0 and moveIdx <= self.cellCount then
		self:updateItemPos(moveIdx, isAdd);
	end
end

function Lua_WildStageList.Get:mousePosition()
	if self.showMode == Lua_AxisDefine.Horizontal then
		return CommonUtil.mousePositionX;
	end
	return CommonUtil.mousePositionY;
end

function Lua_WildStageList:getItemByIdx(idx)
	local len = self.showList:getSize();
	for i = 1, len do
		if self.showList[i].itemIdx == idx then
			return self.showList[i];
		end
	end
	return nil;
end

function Lua_WildStageList:updateItemPos(idx, isMoveUp)
	-- print(self.selectIdx, idx)
	self.prevIdx = self.selectIdx;
	local item, itemY, itemSX, itemSY, alphaValue, len;
	if isMoveUp then
		if self.selectIdx == 1 then
			return;
		end
		self.showList:sort("itemIdx", false);
		item = self:getItemByIdx(self.selectIdx);
		len = self.showList:getSize();
		if item then
			itemY = self.targetPosY - self.cellHeight;
			item = self:getCellFromPool();
			item:setSiblingIndex(len);
			item:setScale(1, 1, 1);
			item:setLocation(0, itemY, 0);
			item:setItemIdx(idx);
			item:setAlpha(0);
			item:setData(self.data[idx]);
			item:setState(false);
		end

		len = self.showList:getSize();
		for i = 1, len do
			item = self.showList[i];
			item:setData(self.data[item.itemIdx]);
			TweenUtil.getInstance():stop(item.content);
			if item.itemIdx == idx then
				item:setState(true);
				item:setData(self.data[item.itemIdx]);
				TweenUtil.getInstance():addTweenTargetAlpha(item.content, self._moveTime, 0, 1, false);
				TweenUtil.getInstance():addTween(item.content, self._moveTime, 0, 
					0, self.targetPosY, 0, 
					0, 0, 0, 
					1, 1, 1, 
					nil, nil, 0, false);
			else
				item:setState(false);
				TweenUtil.getInstance():addTweenTargetAlpha(item.content, self._moveTime, 0, -self.alphaChange, false);
				TweenUtil.getInstance():addTween(item.content, self._moveTime, 0, 
					0, item.itemY + self.blockSizeY, 0, 
					0, 0, 0, 
					1 - i * 0.2, 1 - i * 0.2, 1, 
					nil, nil, 0, false);
			end
		end
	else
		if self.selectIdx == self.cellCount then
			return;
		end
		self.showList:sort("itemIdx", false);
		len = self.showList:getSize();
		item = self.showList[len];
		if item and item.itemIdx < self.cellCount then
			itemY = item.posY + self.blockSizeY;
			itemSX = item.itemSX;
			itemSY = item.itemSY;
			alphaValue = item.alphaValue;

			local value = item.itemIdx + 1;
			item = self:getCellFromPool();
			item:setSiblingIndex(0);
			item:setScale(itemSX - 0.2, itemSY - 0.2, 1);
			item:setLocation(0, itemY, 0);
			item:setItemIdx(value);
			item:setAlpha(alphaValue - self.alphaChange);
			item:setData(self.data[value]);
			item:setState(false);
		end

		len = self.showList:getSize();
		for i = 1, len do
			item = self.showList[i];
			item:setData(self.data[item.itemIdx]);
			TweenUtil.getInstance():stop(item.content);
			if item.itemIdx == self.selectIdx then
				item:setState(false);
				TweenUtil.getInstance():addTweenTargetAlpha(item.content, self._moveTime / 2, 0, -1, false);
				TweenUtil.getInstance():addTween(item.content, self._moveTime / 2, 0, 
					0, item.itemY - self.blockSizeY, 0, 
					0, 0, 0, 
					1, 1, 1, 
					nil, nil, 0, false);

			else
				item:setState(item.itemIdx == (self.selectIdx + 1));
				TweenUtil.getInstance():addTweenTargetAlpha(item.content, self._moveTime, self._moveTime / 2, 1 - (i - 2) * self.alphaChange, false);
				TweenUtil.getInstance():addTween(item.content, self._moveTime, self._moveTime / 2, 
					0, item.itemY - self.blockSizeY, 0, 
					0, 0, 0, 
					item.itemSX + 0.2, item.itemSY + 0.2, 1, 
					nil, nil, 0, false);
			end
		end
	end

	self.selectIdx = idx;
	self.isMoveUp = isMoveUp;
	self:startTimer();
end

function Lua_WildStageList:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		if self.isMoveUp then
			Lua_CommonUtil.delayCall(self._moveTime, self, self.onTweenCompleted);
		else
			Lua_CommonUtil.delayCall(self._moveTime + self._moveTime / 2, self, self.onTweenCompleted);
		end
	end
end

function Lua_WildStageList:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		Lua_CommonUtil.removeTimer(self, self.onTweenCompleted);
	end
end

function Lua_WildStageList:onTweenCompleted()
	self.moveTime = 0.3;
	local len = self.showList:getSize();
	local item;
	if self.isMoveUp then
		while len > 0 do
			item = self.showList[len];
			TweenUtil.getInstance():stop(item.content, true);
			if item.itemIdx == self.selectIdx then
				item:setScale(1, 1, 1);
				item:setLocation(0, self.targetPosY, 0);
				item:setAlpha(1);
				item:setState(true);
			else
				-- print(len, item.itemIdx, 1 - len * self.alphaChange)
				item:setScale(item.itemSX - 0.2, item.itemSY - 0.2, 1);
				item:setLocation(0, item.itemY + self.blockSizeY, 0);
				item:setAlpha(1 - len * self.alphaChange);
				item:setState(false);
			end

			if not self:checkItemInBound(item) then
				self:returnCellToPool(item);
				self.showList:remove(len);
			end
			len = len - 1;
		end
	else
		local num = 0;
		while len > 0 do
			item = self.showList[len];
			TweenUtil.getInstance():stop(item.content, true);
			item:setLocation(0, item.itemY - self.blockSizeY, 0);
			if item.itemIdx == self.prevIdx then
				item:setScale(1, 1, 1);
				item:setAlpha(0);
			else
				num = num + 1;
				item:setScale(item.itemSX + 0.2, item.itemSY + 0.2, 1);
				item:setAlpha(1 - (len - 2) * self.alphaChange);
			end
			item:setState(item.itemIdx == self.selectIdx);

			if not self:checkItemInBound(item) or item.itemY < self.targetPosY then
				self:returnCellToPool(item);
				self.showList:remove(len);
			end
			len = len - 1;
		end
	end
	self.bTimer = false;
end

function Lua_WildStageList:checkItemInBound(item)
	if item.itemY > self.minY - self.blockSizeY and item.itemY < self.maxY + self.blockSizeY then
		return true;
	end
	return false;
end