-- 蛮荒跃境
checkRequire("Lua_WildStageList");
Lua_WildStagePanel = class("Lua_WildStagePanel", Lua_DisplayObject)
function Lua_WildStagePanel:ctor(p)
	self:superCall("ctor", p, "WildStagePanel_skin");
end

function Lua_WildStagePanel:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("WILD_SECRET_STAGE_INFO", self, self.updateServerInfo);
	self:addLuaEvent("WILD_SECRET_STAGE_REWARD", self, self.updateRewardInfo);

	self.itemList = Lua_WildStageList.new(self.content, 697, 1274 + self.adaptHeight);
	self.itemList:setSiblingIndex(0);
	self.itemList:setLocation(0, 28, 0);
	self.itemList:setListCell(Lua_WildStageLayerItem, 697, 854);
	self.itemList:setCellSpacing(0, -550);

	self.rewardRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.WildSecret_Stage_Reward);
	self.rewardRedPoint:setRectAnchor(7);
	self.rewardRedPoint:setLocation(315, 328);

	self.dailyRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.WildSecret_Stage_DailyReward);
	self.dailyRedPoint:setRectAnchor(7);
	self.dailyRedPoint:setLocation(315, 220);

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.checkRank:addClickFuntion(self, self.onCheckRank);
	self.rewardBg:addClickFuntion(self, self.onCheckReward);
	self.dailyIcon:addClickFuntion(self, self.onDailyReward);

	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sStageInfo();
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sStageReward();
end

function Lua_WildStagePanel:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.rewardRedPoint then
		self.rewardRedPoint:dispose();
		self.rewardRedPoint = nil;
	end
	if self.dailyRedPoint then
		self.dailyRedPoint:dispose();
		self.dailyRedPoint = nil;
	end
	self:superCall("dispose");
end

function Lua_WildStagePanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.itemList:setContentRect(697, 1274 + adaptHeight);
end

function Lua_WildStagePanel:updateServerInfo()
	local arr = DataCenter.wildSecretData.stageFloorArr;
	self.itemList:setData(arr);
	if self.isFirstEnter == false then
		self.itemList.moveTime = 1;
		self.itemList:moveToIndex(DataCenter.wildSecretData.curFloor, false);
	else
		self.itemList:moveToIndex(DataCenter.wildSecretData.curFloor, true);
	end
	self.isFirstEnter = false;
	self:updateRewardInfo();
end

function Lua_WildStagePanel:updateRewardInfo()
	local id, str = DataCenter.wildSecretUtil:getStageRewardInfo();
	if id == nil then
		self.rewardObject:SetActive(false);
	else
		self.rewardObject:SetActive(true);
		local config = DataCenter.wildSecretUtil:getStageRewardConfig(id);
		config = getConfig("item", config.reward[1][1]);
		self.rewardIcon:setAltas(config.atlas, config.sprite);
		self.rewardText.text = str;
	end
end

function Lua_WildStagePanel:onCheckHelp(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { des = LanUtil.getValue(701000), posX = 170, posY = -280 });
end

function Lua_WildStagePanel:onCheckRank(go)
	Lua_WindowUtil.openWin("Lua_WildSecretRankWindow", Lua_WinParam.ACTION_OPEN, 1);
end

function Lua_WildStagePanel:onCheckReward(go)
	Lua_WindowUtil.openWin("Lua_WildStageRewardWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_WildStagePanel:onDailyReward(go)
	Lua_WindowUtil.openWin("Lua_WildStageDailyRewardWindow", Lua_WinParam.ACTION_OPEN);
end










Lua_WildStageLayerItem = class("Lua_WildStageLayerItem", Lua_ListCell)
function Lua_WildStageLayerItem:ctor(p)
	self:superCall("ctor", p, "WildStageLayerItem_skin");
	self.itemX = 0;
	self.itemY = 0;
	self.itemSX = 0;
	self.itemSY = 0;
end

function Lua_WildStageLayerItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarIcon:addClickFuntion(self, self.onCheckFriend);
    self.checkIcon:addClickFuntion(self, self.onCheckFriend);
end

function Lua_WildStageLayerItem:dispose()
	if self.uiEff then
		self.uiEff:dispose();
		self.uiEff = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildStageLayerItem:setScale(scaleX, scaleY)
	self:superCall("setScale", scaleX, scaleY);
	self.itemSX = scaleX;
	self.itemSY = scaleY;
end

function Lua_WildStageLayerItem:setLocation(posX, posY, posZ)
	self:superCall("setLocation", posX, posY, posZ);
	self.itemX = posX;
	self.itemY = posY;
end

function Lua_WildStageLayerItem:setLocationOffset(posX, posY, posZ)
	self:setLocation(self.itemX + posX, self.itemY + posY, posZ);
end

function Lua_WildStageLayerItem:checkInBound(posX, posY)
	local minX = self.centerPosX - self.w / 2 * self.scaleX;
	local maxX = self.centerPosX + self.w / 2 * self.scaleX;
	local minY = self.centerPosY - self.h / 2 * self.scaleY;
	local maxY = self.centerPosY + self.h / 2 * self.scaleY;
	if posX >= minX and posX <= maxX and posY >= minY and posY <= maxY then
		return true;
	end
	return false;
end

function Lua_WildStageLayerItem:setItemIdx(value)
	self._itemIdx = value;
	self.content.name = self.classname..value;
end

function Lua_WildStageLayerItem.Get:itemIdx()
	return self._itemIdx;
end

function Lua_WildStageLayerItem:setAlpha(value)
	-- self.alphaValue = value;
	LuaUtil.setObjAlpha(self.content, value);
end

function Lua_WildStageLayerItem.Get:alphaValue()
	return self.bg.alpha;
end

function Lua_WildStageLayerItem:setState(bValue)
	if bValue then
		self.avatarObject:SetActive(self.avatarObject.activeSelf);
		self.nameBg:setEnable(true);
		self.teamText:setEnable(true);
		self.nameText:setEnable(true);
		self.layerText:setEnable(self.layerText.isActive);
		self.incomeLabel:setEnable(self.incomeLabel.isActive);
		self.incomeIcon:setEnable(self.incomeIcon.isActive);
		self.incomeText:setEnable(self.incomeText.isActive);
		self:showEff(self.bShowEff);
	else
		self.avatarObject:SetActive(false);
		self.nameBg:setEnable(false);
		self.teamText:setEnable(false);
		self.nameText:setEnable(false);
		self.layerText:setEnable(false);
		self.incomeLabel:setEnable(false);
		self.incomeIcon:setEnable(false);
		self.incomeText:setEnable(false);
		self:showEff(false);
	end
end

function Lua_WildStageLayerItem:setData(data)
	self.data = data;
	self.bShowEff = false;
	local vo = DataCenter.wildSecretData:getStageFloorVo(data);
	if vo.showRole and tonumber(vo.showRole.id) > 0 then
		self.avatarObject:SetActive(true);
		local avatarId = DataCenter.roleData:getDressUpId(Lua_DressUpDefine.MAINTYPE_HEAD, vo.showRole.dress_info);
		local avatarVo = DataCenter.roleUtil:getDressUpVoById(avatarId);
		self.avatarIcon:setAltas(avatarVo.atlas, avatarVo.sprite);
		self.levelText.text = vo.showRole.level;
	else
		self.avatarObject:SetActive(false);
	end

	self.teamText.text = LanUtil.formateStr(701011, tostring(vo.teamNum));
	self.nameText.text = vo.name;
	self.layerText:setEnable(true);
	self.incomeLabel:setEnable(false);
	self.incomeIcon:setEnable(false);
	self.incomeText:setEnable(false);
	local id = DataCenter.wildSecretData.curStageId;
	local config = DataCenter.wildSecretUtil:getStageConfig(id);
	if data == config.floor then
		self.bShowEff = true;
		if DataCenter.wildSecretData.isFinish then
			self.layerText:setLangValue(701012);
		else
			self.layerText.text = LanUtil.formateStr(10044, tostring(config.stage - 1), tostring(vo.stageNum));
		end

		self.incomeLabel:setEnable(true);
		self.incomeIcon:setEnable(true);
		self.incomeText:setEnable(true);
		self.incomeText.text = LanUtil.formateStr(701086, tostring(DataCenter.wildSecretData.profitPerHour));
	elseif data < config.floor then
		self.layerText:setLangValue(701012);
	else
		self.layerText:setEnable(false);
	end
end

function Lua_WildStageLayerItem:showEff(bValue)
	if bValue then
		if self.uiEff == nil then
			self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_mhmj_csm_02", "ui_mhmj_csm_02", 0, 0);
		end
		self.uiEff:setEnable(true);
	else
		if self.uiEff then
			self.uiEff:setEnable(false);
		end
	end
end

function Lua_WildStageLayerItem:onPressClick()
	if self.data > DataCenter.wildSecretData.curFloor then
		OperateAlert.showLangValue(701013);
	else
		Lua_WindowUtil.openWin("Lua_WildStageWindow", Lua_WinParam.ACTION_OPEN, self.data);
	end
end

function Lua_WildStageLayerItem:onCheckFriend(go)
	Lua_WindowUtil.openWin("Lua_WildStageFriendWindow", Lua_WinParam.ACTION_OPEN, self.data);
end