Lua_WildStageRewardWindow = class("Lua_WildStageRewardWindow", Lua_Window)
function Lua_WildStageRewardWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_WildStageRewardWindow";
	self.skinName = "WildStageRewardWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_WildStageRewardWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("WILD_SECRET_STAGE_REWARD", self, self.updateServerInfo);

	self.itemList = Lua_DragList.new(self.content, 625, 690, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -39, 0);
	self.itemList:setListCell(Lua_WildStageRewardItem, 625, 166, 1);
	self.itemList:setCellSpacing(0, 5);

	self.btnReceive:addClickFuntion(self, self.onReceiveClick);
	self:updateServerInfo();
end

function Lua_WildStageRewardWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_WildStageRewardWindow:updateServerInfo()
	self.itemList:setArrayData(DataCenter.wildSecretUtil.stageRewardList);
end

function Lua_WildStageRewardWindow:onReceiveClick(go)
	if self.clickTime and getTime() - self.clickTime < 0.3 then
		return;
	end
	self.clickTime = getTime();

	local arr = DataCenter.wildSecretUtil.stageRewardList;
	local state;
	for i = 1, arr:getSize() do
		state = DataCenter.wildSecretData:getStageRewardState(arr[i]);
		if state == 1 then
			Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sReceiveStageReward(0);
			return;
		end
	end
	OperateAlert.showLangValue(701006);
end










Lua_WildStageRewardItem = class("Lua_WildStageRewardItem", Lua_ListCell)
function Lua_WildStageRewardItem:ctor(p)
	self:superCall("ctor", p, "WildStageRewardItem_skin");
end

function Lua_WildStageRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_ItemIconList.new(self.content);
	self.itemList:setLocation(-235, -20, 0);
	self.itemList.pivot = 1;
	self.itemList.scaleVal = 0.7;
	self.itemList.canClick = true;

	self.btnReceive:addClickFuntion(self, self.onReceiveClick);
end

function Lua_WildStageRewardItem:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildStageRewardItem:setData(data)
	self.data = data;
	local config = DataCenter.wildSecretUtil:getStageRewardConfig(data);
	local stageCfg = DataCenter.wildSecretUtil:getStageConfig(config.stage_id);
	local curIdx = DataCenter.wildSecretData.curIdx;
	local state = DataCenter.wildSecretData:getStageRewardState(data);

	self.itemList:setArrayData(config.reward);

	self.titleText.text = LanUtil.formateStr(701005, tostring(stageCfg.index));
	self.titleText:resetSize();

	if curIdx >= stageCfg.index then
		self.condText.text = LanUtil.formateStr(10044, Lua_ColorDefine.getColorStr("4CA03E", curIdx), tostring(stageCfg.index));
	else
		self.condText.text = LanUtil.formateStr(10044, Lua_ColorDefine.getColorStr("E14545", curIdx), tostring(stageCfg.index));
	end
	self.condText:setLocation(-288.5 + self.titleText.width + 10, 53);

	if state == 1 then
		self.btnReceive:setEnable(true);
		self.stateIcon:setEnable(false);
	else
		self.btnReceive:setEnable(false);
		self.stateIcon:setEnable(true);
		if state == 2 then
			self.stateIcon:setAltas("common_altas_1", "xui_common_label_12");
		else
			self.stateIcon:setAltas("common_altas_4", "xui_common_label_28");
		end
	end
end

function Lua_WildStageRewardItem:onReceiveClick(go)
	if self.clickTime and getTime() - self.clickTime < 0.3 then
		return;
	end
	self.clickTime = getTime();
	Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sReceiveStageReward(self.data);
end