-- 蛮荒关内
Lua_WildStageWindow = class("Lua_WildStageWindow", Lua_Window)
function Lua_WildStageWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.MAIN_MENU_LAYER;
	self.windowName = "Lua_WildStageWindow";
	self.skinName = "WildStageWindow_skin";
	self.isFullPaving = true;
	self.isFullSizeWin = true;
	self.showBlackMask = true;
end

function Lua_WildStageWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("WILD_SECRET_STAGE_INFO", self, self.updateServerInfo);
	self:addLuaEvent("WILD_SECRET_STAGE_FIGHT_CLICK", self, self.onFightClick);

	self.itemList = Lua_DragList.new(self.content, 720, 1274 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setSiblingIndex(0);
	self.itemList:setLocation(0, 28, 0);
	self.itemList.movementTypeValue = 2;
	self.itemList:setListCell(Lua_WildStageItem, 720, 302, 1);

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
end

function Lua_WildStageWindow:dispose()
	DataCenter.preLoadData:removeBySign("Lua_WildStageLineupWindow", self, self.onSceneShow);
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_WildStageWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.itemList:setContentRect(720, 1274 + self.adaptHeight);
end

function Lua_WildStageWindow:showWin(param)
	self:superCall("showWin", param);

	local vo = DataCenter.wildSecretData:getStageFloorVo(param);
	self.titleText.text = vo.name;

	local config = DataCenter.wildSecretUtil:getStageConfig(param * 1000 + vo.stageNum);
	if config == nil then
		self.incomeText.text = LanUtil.formateStr(701015, tostring(0));
	else
		self.incomeText.text = LanUtil.formateStr(701015, tostring(config.output_per_hour));
	end
	if strIsNullOrEmpty(vo.unlockDes) then
		self.incomeBg:SetDimensions(245, 58);
		self.unlockLabel:setEnable(false);
		self.unlockText:setEnable(false);
	else
		self.incomeBg:SetDimensions(245, 123);
		self.unlockLabel:setEnable(true);
		self.unlockText:setEnable(true);
		self.unlockText.text = vo.unlockDes;
	end

	self:updateServerInfo();
end

function Lua_WildStageWindow:updateServerInfo()
	local arr = DataCenter.wildSecretUtil:getStageList(self.showData);
	local len = arr:getSize();
	self.itemList.customParam = self.showData;
	self.itemList:setArrayData(arr);

	local index = 1;
	for i = 1, len do
		if arr[i] == DataCenter.wildSecretData.curStageId then
			index = i;
			break;
		end
	end
	self.itemList:moveToIndex(index + 1, true, true);
end

function Lua_WildStageWindow:onFightClick(stageId)
	local sceneId = DataCenter.wildSecretData:getStageFightSceneId(stageId);
	if sceneId == 0 then
		sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_WILD_PVE);
	end
	DataCenter.preLoadData:preShowScene("Lua_WildStageLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, stageId, sceneId, 0);
end

function Lua_WildStageWindow:onSceneShow(param, mp, success)
	if not success then return; end 
	local vo = DataCenter.wildSecretData:getStageFloorVo(self.showData);
	local config = DataCenter.wildSecretUtil:getStageConfig(param);
	local data = Lua_LineupWinData.getData(Lua_FightDefine.TEMPLATE_ID_WILD_PVE, config.monser_id, param, nil, vo.teamNum, 47);
	Lua_WindowUtil.openWin("Lua_WildStageLineupWindow", Lua_WinParam.ACTION_OPEN, data);
end

function Lua_WildStageWindow:onCheckHelp(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { des = LanUtil.getValue(701014), posX = 170, posY = -280 });
end










Lua_WildStageItem = class("Lua_WildStageItem", Lua_ListCell)
function Lua_WildStageItem:ctor(p)
	self:superCall("ctor", p, "WildStageItem_skin");
end

function Lua_WildStageItem:buildShowItem()
	self:superCall("buildShowItem");

	self.forceNum = Lua_NumberImage.new(self.showObject);
	self.forceNum:setLocation(85, 23, 0);
	self.forceNum.pivot = 1;
	self.forceNum.numOffsetX = -2;
	self.forceNum.numAtlas = "number";
	self.forceNum.preStr = "xui_zl1_number_0";

	self.btnFight:addClickFuntion(self, self.onFightClick);
end

function Lua_WildStageItem:dispose()
	if self.forceNum then
		self.forceNum:dispose();
		self.forceNum = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_WildStageItem:setCustomParam(floorId)
	self.floorId = floorId;
end

function Lua_WildStageItem:setData(data)
	self.data = data;

	local vo = DataCenter.wildSecretData:getStageFloorVo(self.floorId);
	self.bg:setEnable(true);
	if data == 99999 then
		self.bg:setUrl(vo.bgPath2);
		self.lockIcon:setEnable(false);
		self.maskBg:setEnable(false);
		self.indexText:setEnable(false);
		self.btnFight:setEnable(false);
		self.showObject:SetActive(false);
		self.completeLabel:setEnable(false);
		if self.itemList then
			self.itemList:setEnable(false);
		end
	else
		self.bg:setUrl(vo.bgPath);
		local config = DataCenter.wildSecretUtil:getStageConfig(data);
		self.indexText:setEnable(true);
		self.indexText.text = config.stage;

		local curStageId = DataCenter.wildSecretData.curStageId;
		if data > curStageId then
			self.lockIcon:setEnable(true);
			self.maskBg:setEnable(true);
			self.btnFight:setEnable(false);
			self.showObject:SetActive(false);
			self.completeLabel:setEnable(false);
			if self.itemList then
				self.itemList:setEnable(false);
			end
		else
			self.lockIcon:setEnable(false);
			self.maskBg:setEnable(false);
			if (data < curStageId) or (data == curStageId and DataCenter.wildSecretData.isFinish) then
				self.btnFight:setEnable(false);
				self.completeLabel:setEnable(true);
			else
				self.btnFight:setEnable(true);
				self.completeLabel:setEnable(false);
			end
			self.showObject:SetActive(true);
			
			if self.itemList == nil then
				self.itemList = Lua_ItemIconList.new(self.content);
				self.itemList:setLocation(0, -23, 0);
				self.itemList.scaleVal = 0.58;
			end
			self.itemList:setEnable(true);
			self.itemList:setArrayData(config.reward);

			config = Lua_MonsterPlayerConfigData.getConfigData(config.monser_id);
			local force = 0;
			for i = 1, #config.force do
				force = force + config.force[i];
			end
			self.forceNum.num = force;

			self.enemyLabel:resetSize();
			local width = self.enemyLabel.width + self.forceIcon.width + self.forceNum.totalWidth;
			LuaUtil.setObjPos(self.showObject, -width / 2, 23, 0);
		end
	end
end

function Lua_WildStageItem:onPressClick()
	if self.itemList then
		self.itemList:onBoundClick();
	end
end

function Lua_WildStageItem:onFightClick(go)
	if DataCenter.wildSecretData.isFightLimit then
		OperateAlert.showLangValue(701088);
		return;
	end
	Lua_MsgUtil.callFunc("WILD_SECRET_STAGE_FIGHT_CLICK", self.data);
end